# coding:utf8

"""Simplified Chinese dictionary"""

# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN

zh_CN = {
    "LANGUAGE": "简体中文",
    "LANGUAGE-TAG": "zh_CN",

    # Strings for Windows NSIS installer
    "installer-language-file": "SimpChinese.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
    "installer-associate": "将Syncplay与多媒体文件关联。",
    "installer-shortcut": "在以下位置创建快捷方式:",
    "installer-start-menu": "开始菜单",
    "installer-desktop": "桌面",
    "installer-quick-launch-bar": "快速启动栏",
    "installer-automatic-updates": "自动检查更新",
    "installer-uninstall-configuration": "删除配置文件",

    # Client notifications
    "config-cleared-notification": "设置已清除。 当你存储一个有效的配置时，更改将被保存。",

    "relative-config-notification": "已加载的相对配置文件:{}",

    "connection-attempt-notification": "正在尝试连接{}:{}",  # Port, IP
    "reconnection-attempt-notification": "服务器连接中断，正在尝试重连",
    "disconnection-notification": "与服务器连接中断",
    "connection-failed-notification": "服务器连接失败",
    "connected-successful-notification": "服务器连接成功",
    "retrying-notification": "%s，%d秒内将重试...",  # Seconds
    "reachout-successful-notification": "成功连入{}（{}）",

    "rewind-notification": "与{}不同步，已回放",  # User
    "fastforward-notification": "与{}不同步，已快进",  # User
    "slowdown-notification": "与{}不同步，正在慢速播放",  # User
    "revert-notification": "播放速度恢复一倍速",

    "pause-notification": "{}暂停了 ({})",  # User, Time - TODO: Change into format "{} paused at {}" in line with English message
    "unpause-notification": "{}重新开始播放",  # User
    "seek-notification": "{}从{}跳转到{}",  # User, from time, to time

    "current-offset-notification": "当前偏移量：{}秒",  # Offset

    "media-directory-list-updated-notification": "Syncplay的媒体文件目录已更新。",

    "room-join-notification": "{}加入了'{}'房间",  # User
    "left-notification": "{}离开了房间",  # User
    "left-paused-notification": "{}离开了房间，{}暂停了",  # User who left, User who paused
    "playing-notification": "{}正在播放'{}' (时长{})",  # User, file, duration
    "playing-notification/room-addendum": "正在'{}'房间",  # Room

    "not-all-ready": "{}还未准备",  # Usernames
    "all-users-ready": "所有人已准备（共{}人）",  # Number of ready users
    "ready-to-unpause-notification": "您已准备，按下播放键可继续播放",
    "set-as-ready-notification": "您已准备",
    "set-as-not-ready-notification": "您已取消准备",
    "autoplaying-notification": "{}秒后将自动开始...",  # Number of seconds until playback will start

    "identifying-as-controller-notification": "用密码'{}'认证为管理员...",
    "failed-to-identify-as-controller-notification": "{}未能成为管理员",
    "authenticated-as-controller-notification": "{}成为了管理员",
    "created-controlled-room-notification": "已创建房间：'{}' ，密码是'{}'。请保存好以上信息以备用！\n\n只有房主或管理员可以暂停，继续播放，跳转播放，改变播放列表。每个人都与房主或管理员的播放进度同步。\n\n最近观看过的人都可加入'{}'房间，但只有房主或管理员在加入'{}'房间时才会自动认证为管理员。",  # RoomName, operatorPassword, roomName, roomName:operatorPassword

    "other-set-as-ready-notification": "{} was set as ready by {}",  # User set as ready, user who set them as ready # TODO: Translate
    "other-set-as-not-ready-notification": "{} was set as not ready by {}", # User set as not ready, user who set them as not ready # TODO: Translate

    "file-different-notification": "您正在播放的视频与{}不一致",  # User
    "file-differences-notification": "你们播放的视频文件{}不一致",  # Differences
    "room-file-differences": "播放文件不同点：{}",  # File differences (filename, size, and/or duration)
    "file-difference-filename": "名称",
    "file-difference-filesize": "大小",
    "file-difference-duration": "时长",
    "alone-in-the-room": "您正在一人观看",

    "different-filesize-notification": "（其他人的视频文件大小和您的不一致！）",
    "userlist-playing-notification": "{}正在播放：",  # Username
    "file-played-by-notification": "{}由以下用户播放：",  # File
    "no-file-played-notification": "{}无视频供开始播放",  # Username
    "notplaying-notification": "以下用户没有视频供开始播放：",
    "userlist-room-notification":  "房间'{}'里面有：",  # Room
    "userlist-file-notification": "视频文件",
    "controller-userlist-userflag": "管理员",
    "ready-userlist-userflag": "已准备",

    "update-check-failed-notification": "无法自动检测Syncplay{}版本是否最新。是否前往https://syncplay.pl/手动更新？",  # Syncplay version
    "syncplay-uptodate-notification": "Syncplay版本已最新",
    "syncplay-updateavailable-notification": "Syncplay已有更新版本。是否前往最新版本页面？",

    "mplayer-file-required-notification": "如使用mplayer播放器，您需要在开始前手动加入视频文件。",
    "mplayer-file-required-notification/example": "使用示例：syncplay [options] [url|path/]filename",
    "mplayer2-required": "Syncplay与MPlayer 1.x版本不兼容，请使用mplayer2或mpv（推荐）播放器",

    "unrecognized-command-notification": "未知命令",
    "commandlist-notification": "您可使用如下命令：",
    "commandlist-notification/room": "\tr [name] - 切换房间",
    "commandlist-notification/list": "\tl - 显示房间所有用户",
    "commandlist-notification/undo": "\tu - 撤销上次跳转",
    "commandlist-notification/pause": "\tp - 暂停/继续播放",
    "commandlist-notification/seek": "\t[s][+-]time - 跳转指定时长，如果未输入 + 或 - ，将会跳转到输入的时间节点（时间节点输入格式可为秒或分：秒）",
    "commandlist-notification/offset": "\to[+-]duration - 将本地的播放偏移量设置为给定时长（输入格式可为秒或分：秒），您的本地播放进度将与服务器不一致，因此极不推荐使用该设置",
    "commandlist-notification/help": "\th - 帮助菜单",
    "commandlist-notification/toggle": "\tt - 准备/取消准备",
    "commandlist-notification/setready": "\tsr [name] - sets user as ready",  # TODO: Translate
    "commandlist-notification/setnotready": "\tsn [name] - sets user as not ready",  # TODO: Translate
    "commandlist-notification/create": "\tc [name] - 以给定房间名创建一个由您管理的房间",
    "commandlist-notification/auth": "\ta [password] - 用给定密码来认证为管理员",
    "commandlist-notification/chat": "\tch [message] - 发送聊天信息",
    "commandList-notification/queue": "\tqa [file/url] - 在播放列表最后添加文件或URL",
    "commandList-notification/queueandselect": "\tqas [file/url] - 在播放列表最后添加文件或URL并选中",
    "commandList-notification/playlist": "\tql - 显示当前播放列表",
    "commandList-notification/select": "\tqs [index] - 选中播放列表中指定序号的视频",
    "commandList-notification/next": "\tqn - select next entry in the playlist", # TODO: Translate
    "commandList-notification/delete": "\tqd [index] - 删除播放列表中指定序号的视频",
    "syncplay-version-notification": "当前Syncplay版本为{}",  # syncplay.version
    "more-info-notification": "更多信息请参照{}",  # projectURL

    "gui-data-cleared-notification": "Syncplay已经清除了GUI使用的路径和窗口状态数据。",
    "language-changed-msgbox-label": "当您运行Syncplay时，界面将切换为中文",
    "promptforupdate-label": "是否让Syncplay自动检查更新？",

    "media-player-latency-warning": "警告：播放器用了{}秒响应。如果您遇到播放不同步问题，请关闭其他应用以清理内存。如果仍无法解决问题，建议您更换其他播放器。",  # Seconds to respond
    "mpv-unresponsive-error": "mpv播放器在{}秒之内无反应，可能出现故障。请尝试重启Syncplay。",  # Seconds to respond

    # Client prompts
    "enter-to-exit-prompt": "Press enter to exit\n",

    # Client errors
    "missing-arguments-error": "缺少一些必要的参数，使用--help命令查看详细信息",
    "server-timeout-error": "与服务器的连接超时",
    "mpc-slave-error": "无法在从属模式下启动MPC！",
    "mpc-version-insufficient-error": "MPC版本过低，请使用mpc-hc{}以上版本",
    "mpc-be-version-insufficient-error": "MPC版本过低，请使用mpc-be{}以上版本",
    "mpv-version-error": "Syncplay与此版本的mpv不兼容。请使用其他版本的mpv（例如：Git HEAD）。",
    "mpv-failed-advice": "mpv不能启动的原因可能是由于使用了不支持的命令行参数或不支持的mpv版本。",
    "player-file-open-error": "播放器打开文件失败",
    "player-path-error": "播放器路径设置不正确。支持的播放器有：mpv、mpv.net、VLC、MPC-HC、MPC-BE、mplayer2和IINA。",
    "hostname-empty-error": "主机名不能是空的",
    "empty-error": "{}不能是空的",  # Configuration
    "media-player-error": "媒体播放器错误：\"{}\"",  # Error line
    "unable-import-gui-error": "无法导入GUI库。如果你没有安装PySide，GUI则无法工作，请安装PySide。 If you want to run Syncplay in console mode then run it with the --no-gui command line switch. See https://syncplay.pl/guide/ for more details.", # TODO: Translate end of message and update second sentence to be a translation of "You need to have the correct version of PySide installed for the GUI to work."
    "unable-import-twisted-error": "无法导入Twisted。请安装Twisted v16.4.0或更高版本。",

    "arguments-missing-error": "缺少一些必要的参数，使用--help命令查看详细信息",

    "unable-to-start-client-error": "无法启动客户端",

    "player-path-config-error": "播放器路径设置不正确。支持的播放器有：mpv、mpv.net、VLC、MPC-HC、MPC-BE、mplayer2和IINA。",
    "no-file-path-config-error": "在启动播放器之前，必须选择要播放的文件",
    "no-hostname-config-error": "主机名不能是空的",
    "invalid-port-config-error": "端口无效",
    "empty-value-config-error": "{}不能是空的",  # Config option

    "not-json-error": "不是一个json编码的字符串\n",
    "hello-arguments-error": "Not enough Hello arguments\n",  # DO NOT TRANSLATE
    "version-mismatch-error": "客户端和服务器的版本不匹配\n",
    "vlc-failed-connection": "连接VLC失败。如果你没有安装syncplay.lua并且使用最新版本的VLC，那么请参考https://syncplay.pl/LUA/。Syncplay和VLC 4目前并不兼容，所以请使用VLC 3或mpv等替代软件。",
    "vlc-failed-noscript": "VLC报告没有安装syncplay.lua接口脚本。请参考https://syncplay.pl/LUA/获得指导。",
    "vlc-failed-versioncheck": "Syncplay不支持这个版本的VLC。",
    "vlc-initial-warning": 'VLC无法给Syncplay提供准确进度信息，尤其是在播放.mp4和.avi文件时。如果您遇到了跳转错误的问题，请使用其他播放器例如<a href="https://mpv.io/">mpv</a>（或者为Windows用户提供的<a href="https://github.com/stax76/mpv.net/">mpv.net</a>）。',

    "feature-sharedPlaylists": "共享播放列表",  # used for not-supported-by-server-error
    "feature-chat": "聊天",  # used for not-supported-by-server-error
    "feature-readiness": "准备状态",  # used for not-supported-by-server-error
    "feature-managedRooms": "房间管理",  # used for not-supported-by-server-error
    "feature-setOthersReadiness": "readiness override",  # used for not-supported-by-server-error # TODO: Translate

    "not-supported-by-server-error": "该服务器不支持{}功能",  # feature
    "shared-playlists-not-supported-by-server-error": "服务器可能不支持共享播放列表的功能。为确保其正常运行，需要一个运行Syncplay {}以上版本的服务器，但服务器是运行Syncplay {}的。",  # minVersion, serverVersion
    "shared-playlists-disabled-by-server-error": "在服务器配置中，共享播放列表功能已被禁用。要使用这一功能，你需要连接到其他服务器。",

    "invalid-seek-value": "无效的跳转值",
    "invalid-offset-value": "无效的偏移值",

    "switch-file-not-found-error": "无法切换到视频文件'{0}'。Syncplay只在指定的媒体目录中查找文件。",  # File not found
    "folder-search-timeout-error": "在媒体目录中搜索媒体文件时，由于在'{}'中搜索时间过长而中止 (after having processed the first {} files)。如果你在要搜索的媒体文件夹列表中选择了一个子文件夹过多的文件夹，就会出现这种情况。为了使自动文件切换再次工作，请在菜单栏中选择\"文件->设置媒体目录\"，并删除这个目录或用一个适当的子文件夹替换它。如果这个文件夹实际上是适当的，那么你可以通过选择\"文件->设置媒体目录\"并按\"确定\"来重新启用它。",  # Folder, Files processed - TODO: Update translation (refer back to original English text)
    "folder-search-timeout-warning": "Warning: It has taken {} seconds to scan {:,} files in the folder '{}'. This will occur if you select a folder with too many sub-folders in your list of media folders to search through or if there are too many files to process.",  # Folder, Files processed. Note: {:,} is {} but with added commas seprators. TODO: Translate
    "folder-search-first-file-timeout-error": "搜索'{}'中的媒体文件时，由于访问该目录的时间太长而被中止。如果该目录位于网络驱动器，或者如果你配置了你的驱动器在一段时间不活动后停止工作，就会发生这种情况。为了能够自动切换播放文件，请进入\"文件->设置媒体目录\"，并删除该目录或解决这个问题（还可尝试其他解决方式，例如，改变省电设置）。",  # Folder
    "added-file-not-in-media-directory-error": "你在'{}'中加载了一个文件，该媒体目录尚未保存。你可以通过选择菜单栏中的\"文件->设置媒体目录\"将其保存为指定媒体目录。",  # Folder
    "no-media-directories-error": "没有设置媒体目录。为了使共享播放列表和文件切换功能正常工作，请选择\"文件->设置媒体目录\"，并指定Syncplay应该在哪里寻找媒体文件。",
    "cannot-find-directory-error": "无法找到媒体目录'{}'。要更新您的媒体目录列表，请从菜单栏中选择\"文件->设置媒体目录\"，并指定Syncplay应该在哪里寻找媒体文件。",

    "failed-to-load-server-list-error": "载入公共服务器列表失败。请在您的浏览器中访问https://www.syncplay.pl/以获得更多信息。",

    # Client arguments
    "argument-description": '通过网络来同步多个媒体播放器的解决方案',
    "argument-epilog": '如果没有提供可选值，将使用配置文件中的值',
    "nogui-argument": '不显示GUI',
    "host-argument": "服务器地址",
    "name-argument": '用户名',
    "debug-argument": '调试模式',
    "force-gui-prompt-argument": '显示配置提示信息',
    "no-store-argument": "不要将值保存在.syncplay",
    "room-argument": '默认房间',
    "password-argument": '服务器密码',
    "player-path-argument": '播放器路径',
    "file-argument": '待播放文件',
    "args-argument": '播放器选项，如果你需要传递以-开头的选项，请在它们前面加上一个\'--\'开头',
    "clear-gui-data-argument": '重置存储为QSettings的路径和窗口状态GUI数据。',
    "language-argument": 'Syncplay消息的语言 (de/en/ru/it/es/pt_BR/pt_PT/tr/fr/zh_CN)',

    "version-argument": '显示版本信息',
    "version-message": "您正在使用Syncplay version {} ({})",

    "load-playlist-from-file-argument": "从文本文件中加载播放列表（每一行代表一个文件）",


    # Client labels
    "config-window-title": "Syncplay设置",

    "connection-group-title": "连接设置",
    "host-label": "服务器地址: ",
    "name-label":  "用户名（可选）:",
    "password-label":  "服务器密码（若需要）:",
    "room-label": "默认房间: ",
    "roomlist-msgbox-label": "编辑房间列表（每行一个房间）",

    "media-setting-title": "播放器设置",
    "executable-path-label": "播放器路径:",
    "media-path-label": "视频文件路径（可选）:",
    "player-arguments-label": "播放器参数（若需要）:",
    "browse-label": "选择...",
    "update-server-list-label": "更新列表",

    "more-title": "高级设置",
    "never-rewind-value": "从不",
    "seconds-suffix": " 秒",
    "privacy-sendraw-option": "原始数据",
    "privacy-sendhashed-option": "哈希加密",
    "privacy-dontsend-option": "不共享",
    "filename-privacy-label": "是否共享文件名:",
    "filesize-privacy-label": "是否共享文件大小:",
    "checkforupdatesautomatically-label": "自动为我检查Syncplay更新信息",
    "autosavejoinstolist-label": "将加入的房间添加到房间列表中",
    "slowondesync-label": "进度过快时慢速播放（MPC-HC/BE播放器不支持）",
    "rewindondesync-label": "进度过快时直接跳转（推荐）",
    "fastforwardondesync-label": "进度过慢时直接跳转（推荐）",
    "dontslowdownwithme-label": "进度过慢时不用让其他人与我同步（试验功能）",
    "pausing-title": "暂停设置",
    "pauseonleave-label": "当其他人离开时暂停（例如其他人掉线）",
    "readiness-title": "初始准备状态",
    "readyatstart-label": "自动将我设置为\"已准备\"状态",
    "forceguiprompt-label": "不要总是打开Syncplay设置窗口",  # (Inverted)
    "showosd-label": "启用OSD信息",

    "showosdwarnings-label": "包括警告信息（例如，当文件不同时，用户没有准备好）",
    "showsameroomosd-label": "包括在你的房间中的活动",
    "shownoncontrollerosd-label": "包括在管理的房间中的非管理员的活动",
    "showdifferentroomosd-label": "包括其他房间的活动",
    "showslowdownosd-label": "包括慢速播放/恢复一倍速的通知",
    "language-label": "语言设置",
    "automatic-language": "默认（{}）",  # Default language
    "showdurationnotification-label": "时长不匹配时警告",
    "basics-label": "基本设置",
    "readiness-label": "播放/暂停设置",
    "misc-label": "其他设置",
    "core-behaviour-title": "主房间行为设置",
    "syncplay-internals-title": "Syncplay内部设置",
    "syncplay-mediasearchdirectories-title": "检索媒体文件的目录",
    "syncplay-mediasearchdirectories-label": "检索媒体文件的目录（每行一个目录）",
    "sync-label": "同步设置",
    "sync-otherslagging-title": "如果您播放进度过快...",
    "sync-youlaggging-title": "如果您播放进度过慢...",
    "messages-label": "消息设置",
    "messages-osd-title": "屏幕显示消息设置",
    "messages-other-title": "其他显示消息设置",
    "chat-label": "聊天设置",
    "privacy-label": "隐私设置",  # Currently unused, but will be brought back if more space is needed in Misc tab
    "privacy-title": "隐私设定",
    "unpause-title": "如果您点击播放按钮，将切换为已准备状态并且：",
    "unpause-ifalreadyready-option": "继续播放，如果已准备",
    "unpause-ifothersready-option": "继续播放，如果已准备或者房间中其他人已准备（默认）",
    "unpause-ifminusersready-option": "继续播放，如果已准备或房间中其他人都已准备且准备人数达到最小开始人数",
    "unpause-always": "总是继续播放",
    "syncplay-trusteddomains-title": "受信任的网站（用于流媒体服务和托管内容）",

    "chat-title": "聊天信息输入设置",
    "chatinputenabled-label": "允许通过mpv播放器进行聊天",
    "chatdirectinput-label": "允许即时聊天输入（不需要按Enter键发送）",
    "chatinputfont-label": "聊天输入字体设置",
    "chatfont-label": "聊天输入字体",
    "chatcolour-label": "设置字体颜色",
    "chatinputposition-label": "mpv播放器中聊天输入窗口位置",
    "chat-top-option": "顶部",
    "chat-middle-option": "中间",
    "chat-bottom-option": "底部",
    "chatoutputheader-label": "聊天显示设置",
    "chatoutputfont-label": "聊天显示字体",
    "chatoutputenabled-label": "启用媒体播放器中的聊天显示（目前仅支持mpv播放器）",
    "chatoutputposition-label": "现实模式",
    "chat-chatroom-option": "聊天室模式",
    "chat-scrolling-option": "弹幕模式",

    "mpv-key-tab-hint": "按下[TAB]来切换为字母快捷键模式。",
    "mpv-key-hint": "按下[ENTER]来发送聊天信息。按下[ESC]来退出聊天模式。",
    "alphakey-mode-warning-first-line": "你可以暂时使用旧版本mpv绑定的a-z键。",
    "alphakey-mode-warning-second-line": "按[TAB]返回到Syncplay聊天模式。",

    "help-label": "帮助",
    "reset-label": "恢复默认设置",
    "run-label": "运行Syncplay",
    "storeandrun-label": "保存设置并运行Syncplay",

    "contact-label": "欢迎发送邮件至 <a href=\"mailto:dev@syncplay.pl\"><nobr>dev@syncplay.pl</nobr></a>, 在GitHub上<a href=\"https://github.com/Syncplay/syncplay/issues\"><nobr>创建issue</nobr></a>来反馈漏洞或问题，在GitHub上<a href=\"https://github.com/Syncplay/syncplay/discussions\"><nobr>创建discussion</nobr></a>来提出建议或问题， <a href=\"https://www.facebook.com/SyncplaySoftware\"><nobr>在Facebook上喜欢我们</nobr></a>, <a href=\"https://twitter.com/Syncplay/\"><nobr>在Twitter上关注我们</nobr></a>，或者访问<a href=\"https://syncplay.pl/\"><nobr>https://syncplay.pl/</nobr></a>。请勿使用Syncplay发送敏感信息。",

    "joinroom-label": "加入房间",
    "joinroom-menu-label": "加入房间 {}",
    "seektime-menu-label": "跳转到",
    "undoseek-menu-label": "撤销跳转",
    "play-menu-label": "播放",
    "pause-menu-label": "暂停",
    "playbackbuttons-menu-label": "显示播放控制按钮",
    "autoplay-menu-label": "显示自动播放按钮",
    "autoplay-guipushbuttonlabel": "当所有人准备好时开始播放",
    "autoplay-minimum-label": "最小开始人数:",
    "hideemptyrooms-menu-label": "隐藏空房间",

    "sendmessage-label": "发送",

    "ready-guipushbuttonlabel": "我已经准备好了！",

    "roomuser-heading-label": "房间 / 用户",
    "size-heading-label": "大小",
    "duration-heading-label": "时长",
    "filename-heading-label": "名称",
    "notifications-heading-label": "消息通知",
    "userlist-heading-label": "正在播放列表",

    "browseformedia-label": "浏览媒体文件",

    "file-menu-label": "&文件",  # & precedes shortcut key
    "openmedia-menu-label": "&打开媒体文件",
    "openstreamurl-menu-label": "打开 &媒体流URL",
    "setmediadirectories-menu-label": "设置媒体 &目录",
    "loadplaylistfromfile-menu-label": "&从文件加载播放列表",
    "saveplaylisttofile-menu-label": "&保存播放列表到文件",
    "exit-menu-label": "退&出",
    "advanced-menu-label": "&高级",
    "window-menu-label": "&窗口",
    "setoffset-menu-label": "设置&偏移量",
    "createcontrolledroom-menu-label": "&创建管理的房间",
    "identifyascontroller-menu-label": "&认证为管理员",
    "settrusteddomains-menu-label": "设置&受信任的网站",
    "addtrusteddomain-menu-label": "添加{}为受信任的网站",  # Domain

    "edit-menu-label": "&编辑",
    "cut-menu-label": "剪&切",
    "copy-menu-label": "&复制",
    "paste-menu-label": "&粘贴",
    "selectall-menu-label": "&全选",

    "playback-menu-label": "&播放控制",

    "help-menu-label": "&帮助",
    "userguide-menu-label": "打开用户&指南",
    "update-menu-label": "检查&更新",

    "startTLS-initiated": "尝试安全连接",
    "startTLS-secure-connection-ok": "安全连接已建立（{}）",
    "startTLS-server-certificate-invalid": '安全连接建立失败。该服务器使用了无效的证书。这次通信可能被第三方截获。更多详情和故障排除请参见<a href="https://syncplay.pl/trouble">这里</a>。',
    "startTLS-server-certificate-invalid-DNS-ID": "Syncplay不信任这个服务器，因为它使用的是对其主机名无效的证书。",
    "startTLS-not-supported-client": "客户端不支持TLS加密安全连接",
    "startTLS-not-supported-server": "服务器不支持TLS加密安全连接",

    # TLS certificate dialog
    "tls-information-title": "证书详情",
    "tls-dialog-status-label": "<strong>Syncplay正使用加密的连接到{}.</strong>",
    "tls-dialog-desc-label": "用数字证书进行加密，使信息在发送到或来自<br/>服务器{}时保持隐私。",
    "tls-dialog-connection-label": "使用Transport Layer Security (TLS)对信息进行加密。版本为{}，<br/>加密套件{}。",
    "tls-dialog-certificate-label": "由{}颁发的证书有效期至{}。",

    # About dialog
    "about-menu-label": "&关于Syncplay",
    "about-dialog-title": "关于Syncplay",
    "about-dialog-release": "Version {} release {}",
    "about-dialog-license-text": "Licensed under the Apache&nbsp;License,&nbsp;Version 2.0",
    "about-dialog-license-button": "License",
    "about-dialog-dependencies": "Dependencies",

    "setoffset-msgbox-label": "设置偏移量",
    "offsetinfo-msgbox-label": "偏移量（使用指南参见https://syncplay.pl/guide/）:",

    "promptforstreamurl-msgbox-label": "打开媒体流URL",
    "promptforstreamurlinfo-msgbox-label": "媒体流URL",

    "addfolder-label": "添加文件夹",

    "adduris-msgbox-label": "添加URL到播放列表（每行一个）",
    "editplaylist-msgbox-label": "设置播放列表（每行一个）",
    "trusteddomains-msgbox-label": "可以自动切换到的网站（每行一个）",

    "createcontrolledroom-msgbox-label": "创建管理的房间",
    "controlledroominfo-msgbox-label": "输入房间名称\r\n（使用指南参见https://syncplay.pl/guide/）:",

    "identifyascontroller-msgbox-label": "认证为房间管理员",
    "identifyinfo-msgbox-label": "输入房间密码\r\n（使用指南参见https://syncplay.pl/guide/）:",

    "public-server-msgbox-label": "为当前会话选择公共服务器",

    "megabyte-suffix": " MB",

    # Tooltips

    "host-tooltip": "要连接的主机名或IP，可包括端口（例如：syncplay.pl:8999）。只能与同一服务器/端口上的人进行同步播放。",
    "name-tooltip": "您的昵称。无需注册，之后可以任意改变。如果没有指定，则生成随机昵称。",
    "password-tooltip": "只有在连接到私人服务器时才需要密码。",
    "room-tooltip": "连接后加入的房间，可以是任意名称，但你只能与同一房间的人进行同步播放。",

    "edit-rooms-tooltip": "编辑房间列表。",

    "executable-path-tooltip": "您选择的播放器的位置（目前仅支持mpv、mpv.net、VLC、MPC-HC/BE、mplayer2或IINA）。",
    "media-path-tooltip": "要打开的视频或媒体流的位置。如果您使用mplayer2，该项为必填项。",
    "player-arguments-tooltip": "额外的命令行参数/开关，以传递给该媒体播放器。",
    "mediasearcdirectories-arguments-tooltip": "Syncplay将搜索媒体文件的目录，例如，当你使用点击切换功能时。Syncplay将通过子文件夹进行递归搜索。",

    "more-tooltip": "显示不常用的设置。",
    "filename-privacy-tooltip": "向服务器发送当前播放文件名的隐私模式。",
    "filesize-privacy-tooltip": "向服务器发送当前播放文件的大小的隐私模式。",
    "privacy-sendraw-tooltip": "发送该信息而不进行混淆处理。这是大多数功能的默认选项。",
    "privacy-sendhashed-tooltip": "发送信息的哈希版本，使其对其他客户不太可见。",
    "privacy-dontsend-tooltip": "不要向服务器发送这些信息。这提供了最大的隐私保护。",
    "checkforupdatesautomatically-tooltip": "定期到Syncplay网站查看是否有新版本的Syncplay。",
    "autosavejoinstolist-tooltip": "当你加入一个服务器中的房间时，在要加入的房间列表中自动记住房间名称。",
    "slowondesync-tooltip": "在需要时暂时降低播放速率，使您与其他观众同步。在MPC-HC/BE上不支持。",
    "dontslowdownwithme-tooltip": "意味着如果你的播放滞后，其他人不会被减慢或倒退。这对房间管理员很有用。",
    "pauseonleave-tooltip": "如果你被断开连接或有人从你的房间离开，则暂停播放。",
    "readyatstart-tooltip": "在开始时将自己设定为\"准备好了\"（否则你将被设定为\"没有准备好\"，直到你改变你的准备状态。）",
    "forceguiprompt-tooltip": "当用Syncplay打开一个文件时，不显示设置窗口。",  # (Inverted)
    "nostore-tooltip": "用给定的配置运行Syncplay，但不永久存储这些变化。",  # (Inverted)
    "rewindondesync-tooltip": "为了达到同步在需要时跳转当前播放进度。禁用这个选项可能会导致严重的不同步现象!",
    "fastforwardondesync-tooltip": "当与房间管理员不同步时，会向前跳转播放进度（如果 \"进度过慢时不用让其他人与我同步\"被启用，则是跳转到你应当的进度）。",
    "showosd-tooltip": "向媒体播放器OSD发送Syncplay信息。",
    "showosdwarnings-tooltip": "如果出现播放不同的文件，独自在房间里，用户没有准备好等情况，则显示警告。",
    "showsameroomosd-tooltip": "显示与用户所在房间有关的活动的OSD通知。",
    "shownoncontrollerosd-tooltip": "显示OSD对与在管理的房间的非管理员有关的活动的通知。",
    "showdifferentroomosd-tooltip": "显示与用户不在的房间有关的活动的OSD通知。",
    "showslowdownosd-tooltip": "显示因进度不同步而进行慢速播放/恢复一倍速的通知。",
    "showdurationnotification-tooltip": "当一个多部分文件中的一个片段丢失时，这很有用，但可能会导致误报。",
    "language-tooltip": "Syncplay中使用的语言。",
    "unpause-always-tooltip": "如果你按下继续播放，会总是将你设置为已准备并继续播放，而不是只将你设置为已准备。",
    "unpause-ifalreadyready-tooltip": "如果你在没有准备好的情况下按下继续播放，它将把你设定为已准备的状态--再按下继续播放就可以继续播放。",
    "unpause-ifothersready-tooltip": "如果你在没有准备好时按下继续播放，只有在其他人准备好时才会继续播放。",
    "unpause-ifminusersready-tooltip": "如果你在没有准备好时按下继续播放，那么只有在其他人准备好并且达到最小开始人数时，它才会取消暂停。",
    "trusteddomains-arguments-tooltip": "启用共享播放列表时，可以让Syncplay自动切换到的网站。",

    "chatinputenabled-tooltip": "在mpv中启用聊天输入（按回车键聊天，按回车键发送，按Esc键取消）。",
    "chatdirectinput-tooltip": "在mpv中无需按回车键即可进入聊天输入模式。在mpv中按TAB键可以暂时禁用这个功能。",
    "font-label-tooltip": "在mpv中输入聊天信息时使用的字体。只在客户端使用，所以不影响其他人看到的内容。",
    "set-input-font-tooltip": "在mpv中输入聊天信息时使用的字体。只在客户端使用，所以不影响其他人看到的内容。",
    "set-input-colour-tooltip": "在mpv中输入聊天信息时使用的字体颜色。只在客户端使用，所以不影响其他人看到的内容。",
    "chatinputposition-tooltip": "聊天输入文本在mpv中的位置，当你按下回车键进行打字输入时，会出现在mpv中。",
    "chatinputposition-top-tooltip": "将聊天输入放在mpv窗口的顶部。",
    "chatinputposition-middle-tooltip": "将聊天输入放在mpv窗口的中间。",
    "chatinputposition-bottom-tooltip": "将聊天输入放在mpv窗口的底部。",
    "chatoutputenabled-tooltip": "在OSD中显示聊天信息（如果媒体播放器支持）。",
    "font-output-label-tooltip": "聊天显示字体。",
    "set-output-font-tooltip": "显示聊天信息时使用的字体。",
    "chatoutputmode-tooltip": "聊天信息的显示方式。",
    "chatoutputmode-chatroom-tooltip": "在前一行的正下方显示新的聊天行。",
    "chatoutputmode-scrolling-tooltip": "像弹幕一样从左到右滚动显示聊天信息。",

    "help-tooltip": "打开Syncplay.pl网站上的用户指南。",
    "reset-tooltip": "将所有设置重置为默认配置。",
    "update-server-list-tooltip": "连接到syncplay.pl来更新公共服务器的列表。",

    "sslconnection-tooltip": "安全地连接到服务器。点击查看证书详情。",

    "joinroom-tooltip": "离开当前房间，加入指定房间。",
    "seektime-msgbox-label": "跳到指定的时间（格式：秒/分：秒）。使用+/-进行相对跳转。",
    "ready-tooltip": "表示你是否准备好观看。",
    "autoplay-tooltip": "当所有拥有准备就绪指示器的用户都准备好了，并且满足最小开始人数时，自动播放。",
    "switch-to-file-tooltip": "双击即可切换到{}",  # Filename
    "sendmessage-tooltip": "发送消息到房间中。",

    # In-userlist notes (GUI)
    "differentsize-note": "大小不同！",
    "differentsizeandduration-note": "大小和时长不同！",
    "differentduration-note": "时长不同！",
    "nofile-note": "（没有正在播放的视频）",

    # Server messages to client
    "new-syncplay-available-motd-message": "您正在使用Syncplay {}版本，但已有较新的版本可从https://syncplay.pl下载。",  # ClientVersion
    "persistent-rooms-notice": "NOTICE: This server uses persistent rooms, which means that the playlist information is stored between playback sessions. If you want to create a room where information is not saved then put -temp at the end of the room name.", # NOTE: Do not translate the word -temp
    "ready-chat-message": "I have set {} as ready.",  # User # TODO: Translate
    "not-ready-chat-message": "I have set {} as not ready.",  # User # TODO: Translate

    # Server notifications
    "welcome-server-notification": "欢迎使用Syncplay服务端，当前版本{0}",  # version
    "client-connected-room-server-notification": "{0}({2})连接到了房间'{1}'",  # username, host, room
    "client-left-server-notification": "{0}断开了服务器",  # name
    "no-salt-notification": "请注意：为了使该服务器实例生成的房间管理员密码在服务器重新启动时仍然有效，请在今后运行Syncplay服务器时添加以下命令行参数：--salt {}",  # Salt


    # Server arguments
    "server-argument-description": '在网络上同步播放多个媒体播放器实例的解决方案。服务器实例',
    "server-argument-epilog": '如果没有提供选项，将使用_config的值',
    "server-port-argument": '服务器TCP端口',
    "server-password-argument": '服务器密码',
    "server-isolate-room-argument": '房间是否相互隔离？',
    "server-salt-argument": "用于生成管理的房间密码的随机字符串",
    "server-disable-ready-argument": "停用准备就绪功能",
    "server-motd-argument": "取出Motd的文件的路径",
    "server-rooms-argument": "使用和/或创建数据库文件的路径，以存储持久的房间数据。使房间能够在没有观察者的情况下持续存在，并通过重新启动来实现。",
    "server-permanent-rooms-argument": "列出永久房间的文件的路径，即使房间是空的也会被列出（以文本文件的形式，每行列出一个房间）--要求启用永久房间。",
    "server-chat-argument": "是否禁用聊天功能？",
    "server-chat-maxchars-argument": "聊天信息中的最大字符数（默认为{}）", # Default number of characters
    "server-maxusernamelength-argument": "用户名中的最大字符数（默认为{}）。",
    "server-stats-db-file-argument": "使用提供的SQLite db文件启用服务器统计功能",
    "server-startTLS-argument": "使用提供的路径中的证书文件启用TLS连接",
    "server-messed-up-motd-unescaped-placeholders": "每日信息中有未转义的占位符。所有 $ 字符应当重复两遍 ($$).",
    "server-messed-up-motd-too-long": "每日信息过长 - 最大{}个chars, 给出的长度{}",
    "server-listen-only-on-ipv4": "Listen only on IPv4 when starting the server.",
    "server-listen-only-on-ipv6": "Listen only on IPv6 when starting the server.",
    "server-interface-ipv4": "The IP address to bind to for IPv4. Leaving it empty defaults to using all.",
    "server-interface-ipv6": "The IP address to bind to for IPv6. Leaving it empty defaults to using all.",

    # Server errors
    "unknown-command-server-error": "未知命令 {}",  # message
    "not-json-server-error": "非json格式字符串 {}",  # message
    "line-decode-server-error": "非utf-8编码字符串",
    "not-known-server-error": "在发送这条命令之前，你必须被服务器认证",
    "client-drop-server-error": "客户端错误消息： {} -- {}",  # host, error
    "password-required-server-error": "请输入密码",
    "wrong-password-server-error": "密码不正确",
    "hello-server-error": "Not enough Hello arguments",  # DO NOT TRANSLATE

    # Playlists
    "playlist-selection-changed-notification":  "{}换碟了",  # Username
    "playlist-contents-changed-notification": "{}更新了播放列表",  # Username
    "cannot-find-file-for-playlist-switch-error": "切换播放内容时，在媒体目录中找不到{}！",  # Filename
    "cannot-add-duplicate-error": "无法将'{}'第二次添加到播放列表中，因为不允许重复。",  # Filename
    "cannot-add-unsafe-path-error": "不能自动加载{}，因为它不在受信任的网站上。你可以在播放列表中双击该URL，手动切换到该URL，并通过文件->高级->设置受信任网站添加受信任网站。如果你鼠标右键一个URL，那么你可以通过右键菜单将其网站添加为受信任网站。",  # Filename
    "sharedplaylistenabled-label": "启用共享播放列表",
    "removefromplaylist-menu-label": "从播放列表中删除",
    "shuffleremainingplaylist-menu-label": "随机排列未完成的播放列表",
    "shuffleentireplaylist-menu-label": "随机排列整个播放列表",
    "undoplaylist-menu-label": "撤销对播放列表的上一次修改",
    "addfilestoplaylist-menu-label": "将文件添加到播放列表的底部",
    "addurlstoplaylist-menu-label": "将URL添加到播放列表的底部",
    "editplaylist-menu-label": "编辑播放列表",

    "open-containing-folder": "打开包含该文件的文件夹",
    "addyourfiletoplaylist-menu-label": "将文件添加到播放列表",
    "addotherusersfiletoplaylist-menu-label": "添加{}的文件到播放列表",  # [Username]
    "addyourstreamstoplaylist-menu-label": "将媒体流添加到播放列表",
    "addotherusersstreamstoplaylist-menu-label": "添加{}的媒体流流到播放列表",  # [Username]
    "openusersstream-menu-label": "打开{}的媒体流",  # [username]'s
    "openusersfile-menu-label": "打开{}的文件",  # [username]'s

    "setasready-menu-label": "Set {} as ready",  # [Username] # TODO: Translate
    "setasnotready-menu-label": "Set {} as not ready",  # [Username] # TODO: Translate

    "playlist-instruction-item-message": "把文件拖到这里，就可以把它添加到共享播放列表中。",
    "sharedplaylistenabled-tooltip": "房间管理员可以将文件添加到共享播放列表中，以方便大家观看同样的东西。可以在其他设置中配置媒体目录。",

    "playlist-empty-error": "播放列表目前是空的。",
    "playlist-invalid-index-error": "无效的播放列表索引",
}



import os
from syncplay import constants
from syncplay.players.mpv import MpvPlayer
from syncplay.utils import playerPathExists

class MpvnetPlayer(MpvPlayer):


    @staticmethod
    def run(client, playerPath, filePath, args):
            args.extend(constants.MPV_NET_EXTRA_ARGS)
            constants.MPV_NEW_VERSION = True
            constants.MPV_OSC_VISIBILITY_CHANGE_VERSION = True
            return MpvnetPlayer(client, MpvnetPlayer.getExpandedPath(playerPath), filePath, args)

    @staticmethod
    def getDefaultPlayerPathsList():
        l = []
        for path in constants.MPVNET_PATHS:
            p = MpvnetPlayer.getExpandedPath(path)
            if p:
                l.append(p)
        return l


    @staticmethod
    def isValidPlayerPath(path):
        if "mpvnet" in path and MpvnetPlayer.getExpandedPath(path):
            return True
        return False


    @staticmethod
    def getExpandedPath(playerPath):
        if not playerPathExists(playerPath):
            if playerPathExists(playerPath + "mpvnet.exe"):
                playerPath += "mpvnet.exe"
                return playerPath
            elif playerPathExists(playerPath + "\\mpvnet.exe"):
                playerPath += "\\mpvnet.exe"
                return playerPath
        if os.access(playerPath, os.X_OK):
            return playerPath
        for path in os.environ['PATH'].split(':'):
            path = os.path.join(os.path.realpath(path), playerPath)
            if os.access(path, os.X_OK):
                return path


    @staticmethod
    def getIconPath(path):
        return constants.MPVNET_ICONPATH





# coding:utf8

"""Finnish dictionary"""

# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN

fi = {
     "LANGUAGE": "Finnish",
     "LANGUAGE-TAG": "fi",

     # Strings for Windows NSIS installer
     "installer-language-file": "Finnish.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
     "installer-associate": "Aseta Syncplay avaamaan multimedia-tiedostoja.",
     "installer-shortcut": "Luo pikakuvakkeet seuraaviin kohteisiin:",
     "installer-start-menu": "Käynnistä-valikko",
     "installer-desktop": "Työpöytä",
     "installer-quick-launch-bar": "Pikakäynnistyspalkki",
     "installer-automatic-updates": "Tarkista päivitykset automaattisesti",
     "installer-uninstall-configuration": "Poista asetustiedosto.",

     # Client notifications
     "config-cleared-notification": "Asetukset pyyhitty. Muutokset muistetaan tallentaessa kelvolliset asetukset.",

     "relative-config-notification": "Ladattiin hakemiston asetustiedosto(t): {}",

     "connection-attempt-notification": "Yritetään yhdistää kohteeseen {}:{}",  # Port, IP
     "reconnection-attempt-notification": "Yhteys palvelimeen menetettiin, yritetään uudelleenyhdistämistä",
     "disconnection-notification": "Yhteys palvelimeen katkaistu",
     "connection-failed-notification": "Palvelimeen yhdistäminen epäonnistui",
     "connected-successful-notification": "Yhteys muodostettu palvelimeen onnistuneesti",
     "retrying-notification": "%s, Yritetetään uudelleen %d sekunnissa...",  # Seconds
     "reachout-successful-notification": "Tavoitettu onnistuneesti {} ({})",

     "rewind-notification": "Kelattiin taaksepäin käyttäjän {} aikaeron vuoksi",  # User
     "fastforward-notification": "Pikakelattiin käyttäjän {} aikaeron vuoksi",  # User
     "slowdown-notification": "Hidastetaan toistoa käyttäjän {} aikaeron vuoksi",  # User
     "revert-notification": "Palautetaan toistonopeus normaaliksi",

     "pause-notification": "{} tauotti kohdassa {}",  # User, Time
     "unpause-notification": "{} jatkoi toistoa",  # User
     "seek-notification": "{} hyppäsi kohdasta {} kohtaan {}",  # User, from time, to time

     "current-offset-notification": "Nykyinen aikaero: {} sekuntia",  # Offset

     "media-directory-list-updated-notification": "Syncplay:n mediahakemistot on päivitetty.",

     "room-join-notification": "{} liittyi huoneeseen: '{}'",  # User
     "left-notification": "{} poistui",  # User
     "left-paused-notification": "{} poistui, {} tauotti",  # User who left, User who paused
     "playing-notification": "{} toistaa '{}' ({})",  # User, file, duration
     "playing-notification/room-addendum": " huoneessa: '{}'",  # Room

     "not-all-ready": "Ei valmiina: {}",  # Usernames
     "all-users-ready": "Kaikki ovat valmiita ({} käyttäjää)",  # Number of ready users
     "ready-to-unpause-notification": "Asetit itsesi nyt valmiiksi - paina taukoa uudelleen päättääksesi tauon",
     "set-as-ready-notification": "Asetit itsesi valmiiksi",
     "set-as-not-ready-notification": "Ilmaisit ettet ole vielä valmis",
     "autoplaying-notification": "Automaattinen toisto alkaa {}...",  # Number of seconds until playback will start

     "identifying-as-controller-notification": "Tunnistaudutaan huoneen operaattoriksi salasanalla '{}'...",
     "failed-to-identify-as-controller-notification": "{} huoneen operaattoriksi tunnistautuminen epäonnistui.",
     "authenticated-as-controller-notification": "{} tunnistautui huoneen operaattoriksi",
     "created-controlled-room-notification": "Luotiin hallittu huone '{}' salasanalla '{}'. Kirjoita tämä talteen tulevaisuudessa löydettäväksi!\n\nHallinnoiduissa huoneissa kaikkien osallistujien kohdat pidetään synkronoituneena huoneen operaattori(e)n kanssa ja vain he voivat tauottaa, jatkaa tai kelata ja muuttaa soittolistaa.\n\nSinun tulisi pyytää vakiokatsojia liittymään huoneeseen '{}' huoneen operaattorit taas voivat liittyä huoneeseen '{}' tunnistautuakseen automaattisesti.",  # RoomName, operatorPassword, roomName, roomName:operatorPassword

    "other-set-as-ready-notification": "{} was set as ready by {}", # User set as ready, user who set them as ready # TODO: Translate
    "other-set-as-not-ready-notification": "{} was set as not ready by {}", # User set as not ready, user who set them as not ready # TODO: Translate

     "file-different-notification": "Vaikutat toistavan eri tiedostoa verrattuna käyttäjään {}",  # User
     "file-differences-notification": "Tiedostosi poikkeaa seuraavasti: {}",  # Differences
     "room-file-differences": "Tiedostoerot: {}",  # File differences (filename, size, and/or duration)
     "file-difference-filename": "nimi",
     "file-difference-filesize": "koko",
     "file-difference-duration": "kesto",
     "alone-in-the-room": "Olet huoneessa yksin",

     "different-filesize-notification": " (hänen tiedostokokonsa poikkeaa omastasi!)",
     "userlist-playing-notification": "{} toistaa:",  # Username
     "file-played-by-notification": "Toistetaan tiedostoa {}",  # File
     "no-file-played-notification": "{} ei toista mitään tiedostoa",  # Username
     "notplaying-notification": "Käyttäjät, jotka eivät toista mitään:",
     "userlist-room-notification":  "Huoneessa '{}':",  # Room
     "userlist-file-notification": "Tiedosto",
     "controller-userlist-userflag": "Operaattori",
     "ready-userlist-userflag": "Valmiina",

     "update-check-failed-notification": "Syncplay {} ajantasaisuutta ei voitu tarkistaa. Haluatko vierailla osoitteessa https://syncplay.pl/ tarkistaaksesi päivitykset käsin?",  # Syncplay version
     "syncplay-uptodate-notification": "Syncplay on ajantasalla",
     "syncplay-updateavailable-notification": "Syncplayn uusi versio on saatavilla. Haluatko vierailla julkaisusivulla?",

     "mplayer-file-required-notification": "Käytettäessä Mplayer-sovellusta Syncplay vaatii tiedostonimen käynnistettäessä",
     "mplayer-file-required-notification/example": "Käyttöesimerkki: syncplay [argumentit] [osoite|polku/]tiedostonimi",
     "mplayer2-required": "Syncplay ei ole yhteensopiva MPlayer version 1.x kanssa, käytä mplayer2:ta mpv:tä",

     "unrecognized-command-notification": "Tuntematon komento",
     "commandlist-notification": "Käytettävissä olevat komennot:",
     "commandlist-notification/room": "\tr [nimi] - siirry huoneeseen",
     "commandlist-notification/list": "\tl - näytä käyttäjäluettelo",
     "commandlist-notification/undo": "\tu - peru edellinen kohtahaku",
     "commandlist-notification/pause": "\tp - tauota tai päätä tauko",
     "commandlist-notification/seek": "\t[s][+-]kohta - siirry annettuun kohtaan, mikäli + tai - ei ole määritetty, kyseessä on absoluuttinen kohta sekunneissa tai min:sek",
     "commandlist-notification/offset": "\to[+-]kesto - tee aikaero palvelimeen paikallisesti keston verran - tämä ominaisuus on deprekoitu",
     "commandlist-notification/help": "\th - tämä ohje",
     "commandlist-notification/toggle": "\tt - määrittää oletko valmis aloittamaan katselun vaiko et",
    "commandlist-notification/setready": "\tsr [name] - sets user as ready",  # TODO: Translate
    "commandlist-notification/setnotready": "\tsn [name] - sets user as not ready",  # TODO: Translate
     "commandlist-notification/create": "\tc [nimi] - tee tästä huoneesta hallittu",
     "commandlist-notification/auth": "\ta [salasana] - tunnistaudu operaattoriksi salasanalla",
     "commandlist-notification/chat": "\tch [viesti] - lähetä viesti huoneeseen",
     "commandList-notification/queue": "\tqa [tiedosto/osoite] - lisää tiedosto tai osoite soittolistan loppuun",
     "commandList-notification/queueandselect": "\tqas [tiedosto/osoite] - lisää tiedosto tai osoite soittolistan loppuun, sekä valitse se",
     "commandList-notification/playlist": "\tql - näytä nykyinen soittolista",
     "commandList-notification/select": "\tqs [sisällys] - valitse kohde soittolistassa",
     "commandList-notification/next": "\tqn - valitse toistolistalla seuraava kohde",
     "commandList-notification/delete": "\tqd [sisällys] - poista valittu kohde soittolistalta",
     "syncplay-version-notification": "Syncplayn versio: {}",  # syncplay.version
     "more-info-notification": "Lisätietoja osoitteessa: {}",  # projectURL

     "gui-data-cleared-notification": "Syncplay on tyhjentänyt käyttöliittymän polun ja ikkunan tiedot.",
     "language-changed-msgbox-label": "Kieli vaihdetaan Syncplayn uudelleenkäynnistyksen yhteydessä.",
     "promptforupdate-label": "Sallitko Syncplayn tarkistavan päivitykset automaattisesti ajoittain?",

     "media-player-latency-warning": "Varoitus: mediasoittimelta kesti {} sekuntia vastata. Mikäli kohtaat synkronointi-ongelmia, sulje muita sovelluksia vapauttaaksesi järjestelmäresursseja, ja mikäli se ei auta, kokeile toista mediasoitinta.",  # Seconds to respond
     "mpv-unresponsive-error": "mpv ei ole vastannut {} sekuntiin, joten se vaikuttaa toimineen virheellisesti. Käynnistä Syncplay uudelleen.",  # Seconds to respond

     # Client prompts
     "enter-to-exit-prompt": "Paina rivinvaihtonäppäintä (Enter) poistuaksesi\n",

     # Client errors
     "missing-arguments-error": "Joitakin vaadittuja argumentteja uupuu, katso --help",
     "server-timeout-error": "Aikakatkaisu yhdistäessä palvelimeen",
     "mpc-slave-error": "MPC:tä ei voitu käynnistää slave-tilassa!",
     "mpc-version-insufficient-error": "MPC-versio ei ole riittävä, käytä `mpc-hc` >= `{}`",
     "mpc-be-version-insufficient-error": "MPC-versio ei riittävä, käytä `mpc-be` >= `{}`",
     "mpv-version-error": "Syncplay ei ole yhteensopiva tämän mpv-soittimen version kanssa. Käytäthän mpv:n uudempaa julkaisua jotta saat toiston käyntiin(esim. Git HEAD).",
     "mpv-failed-advice": "Syy miksi mpv ei voi käynnistyä voi johtua tukemattomista komentorivin vivuista tai sitten mpv:n versiosta jota ei tueta.",
     "player-file-open-error": "Toistin ei saanut tiedostoa auki",
     "player-path-error": "Toistimen tiedostopolku ei ole oikein asetettu. Tuettuja toisto-ohjelmia ovat: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2, ja IINA",
     "hostname-empty-error": "Palvelinnimi ei voi olla tyhjä",
     "empty-error": "{} ei voi jättää tyhjäksi",  # Configuration
     "media-player-error": "Mediasoitin kohtasi virheen: \"{}\"",  # Error line
     "unable-import-gui-error": "Käyttöliittymäkirjastoja ei saatu tuotua. Mikäli sinulla ei ole PySide asennettuna, tulee sinun asentaa se jotta käyttöliittymä toimisi. If you want to run Syncplay in console mode then run it with the --no-gui command line switch. See https://syncplay.pl/guide/ for more details.", # TODO: Translate end of message and update second sentence to be a translation of "You need to have the correct version of PySide installed for the GUI to work."
     "unable-import-twisted-error": "Twisted:iä ei onnistuttu tuomaan. Asenna Twisted v16.4.0 tai myöhäisempi.",

     "arguments-missing-error": "Joitakin vipuja uupuu, katso apua --help",

     "unable-to-start-client-error": "Asiakasohjelmaa ei saatu käynnistettyä",

     "player-path-config-error": "Toistimen sijaintipolku ei ole asetettu oikein. Tuetut toisto-ohjelmat ovat: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2, ja IINA.",
     "no-file-path-config-error": "Tiedosto pitää valita ennen soittimesi käynnistämistä",
     "no-hostname-config-error": "Palvellinnimi ei voi olla tyhjä",
     "invalid-port-config-error": "Portti tulee olla kelvollinen",
     "empty-value-config-error": "{} ei voi olla tyhjä",  # Config option

     "not-json-error": "Tämä ei ole json-enkoodattu lanka\n",
     "hello-arguments-error": "Not enough Hello arguments\n",  # DO NOT TRANSLATE
     "version-mismatch-error": "Yhteensopimattomuusongelma asiakasohjelman ja palvelimen välillä\n",
     "vlc-failed-connection": "VLC:hen ei saatu yhteyttä. Mikäli et ole asentanut osasta syncplay.lua ja käytät VLC:n tuoreinta julkaisua, katso lisäapua täältä https://syncplay.pl/LUA/ jotta asia ratkeaa. Syncplay ja VLC 4 eivät tällä hetkellä ole yhteensopivia, joten käytä joko VLC 3:a tai vaihtoehtoista toistinta kuten mpv.",
     "vlc-failed-noscript": "VLC ilmoitti että syncplay.lua -liitymää ei ole asennettu. Katsothan https://syncplay.pl/LUA/ saadaksesi lisätietoja.",
     "vlc-failed-versioncheck": "Tämä VLC:n julkaisu ei ole Syncplayn tukema.",
     "vlc-initial-warning": 'VLC ei aina tarjoa aivan tarkkaa toistojanan sijaintitietoa Syncplaylle, erityisesti .mp4 ja .avi tiedostojen kanssa on epätarkkuuksia. Jos kohtaat ongelmia virheellisen kohtahaun suhteen, kokeile vaihtoehtoista mediantoisto-ohjelmaa kuten <a href="https://mpv.io/">mpv</a> (or <a href="https://github.com/stax76/mpv.net/">mpv.net</a> jos olet Windows-käyttäjä).',

     "feature-sharedPlaylists": "jaetut soittoluettelot",  # used for not-supported-by-server-error
     "feature-chat": "keskustelu",  # used for not-supported-by-server-error
     "feature-readiness": "valmius",  # used for not-supported-by-server-error
     "feature-managedRooms": "hallinnoidut huoneet",  # used for not-supported-by-server-error
     "feature-setOthersReadiness": "readiness override",  # used for not-supported-by-server-error # TODO: Translate

     "not-supported-by-server-error": "Tämä {} ominaisuus ei ole tämän palvelimen tukema..",  # feature
     "shared-playlists-not-supported-by-server-error": "Jaetut toistoluettelot eivät välttämättä ole palvelimen tukemia. Varmistaaksesi että kaikki toimii oikein vaaditaan palvelin jossa ajetaan Syncplaytä  {}+, mutta palvelin ajaa Syncplayn versiota {}.",  # minVersion, serverVersion
     "shared-playlists-disabled-by-server-error": "Jaettujen toistoluettelojen ominaisuus on kytketty pois päältä palvelimen asetuksista. Käyttääksesi tätä ominaisuutta sinun tulee yhdistää eri palvelimelle.",

     "invalid-seek-value": "Epäkelp hakuarvo",
     "invalid-offset-value": "Epäkelpo poikkeama-arvo",

     "switch-file-not-found-error": "Ei onnistuttu vaihtamaan tiedostoon '{0}'. Syncplay katsoo määritettyjen mediahakemistojen läpi.",  # File not found
     "folder-search-timeout-error": "Haku median löytämiseksi mediahakemistoista keskeytettiin koska se alkoi viedä liiaksi aikaa käydä läpi '{}' (after having processed the first {:,} files). Tätä ilmenee jos valitset kansion jossa on liikaa alikansioita määritellyn hakemistopolun tiimoilla. Jotta automaattinen tiedostovaihtaminen toimisi jälleen valitse Tiedosto->Aseta mediahakemistot valikkopalkissa ja poista tämä nykyinen hakemisto tai vaihda se sopivaan alikansioon. Mikäli kansio on itseasiassa kelvollinen, täten voit uudelleenvalita sen käyttöön valiten Tiedosto->Aseta mediahakemistot ja kun napsautat 'OK'.", # Folder, Files processed - Note: {:,} is {} but with added commas seprators - TODO: Translate
     "folder-search-timeout-warning": "Warning: It has taken {} seconds to scan {:,} files in the folder '{}'. This will occur if you select a folder with too many sub-folders in your list of media folders to search through or if there are too many files to process.",  # Folder, Files processed. Note: {:,} is {} but with added commas seprators. TODO: Translate
     "folder-search-first-file-timeout-error": "Haku mediaa etsien kohteessa '{}' keskeytettiin koska aikaa kului liian paljon hakemistoon pääsemiseksikään. Tätä voi ilmetä jos kyseessä on verkkoasema tai jos olet määrttänyt aseman sammuttamaan lukutoiminnan tietyn joutilasajan jälkeen. Jotta saat automaattisen tiedostovaihdon jälleen toimimaan mene Tiedosto->Aseta mediakansiotSet Media Directories ja joko poista hakemisto tai ratkaise ongelma (esim. muuttamalla virransäästön asetusta).",  # Folder
     "added-file-not-in-media-directory-error": "Lataus tapahtui ajassa '{}' mutta kyseessä ei ole tunnettu mediakansio. Voit lisätä tämän mediahakemistoksi valiten Tiedosto->Aseta mediahakemistot valikkopalkissa.",  # Folder
     "no-media-directories-error": "Mediahakemistoja ei ole asetettu. Jotta jaetut toistoluettelot ja tiedostovaihdot toimisivat valitse Tiedosto->Aseta mediahakemistot ja määritä mistä Syncplay hakee mediatiedostoja.",
     "cannot-find-directory-error": "Mediahakemistoa '{}' ei löytynyt. Päivittääksesi mediahakemistojesi luettelon valitse Tiedosto->Aseta mediahakemistot valikkopalkista ja määritä mistä Syncplay sitten hakee löytääkseen mediatiedostoja.",

     "failed-to-load-server-list-error": "Julkista palvelinluetteloa ei saatu ladattua. Käy osoitteessa https://www.syncplay.pl/ selaimellasi.",

     # Client arguments
     "argument-description": 'Ratkaisu yhdentää toisto useiden mediantoisto-ohjelmien kesken verkon yli.',
     "argument-epilog": 'Mikäli vaihtoehtoja ei määritetä käytetään _config arvoja',
     "nogui-argument": 'älä näytä käyttöliittymää',
     "host-argument": "palvelimen osoite",
     "name-argument": 'toivottu käyttäjänimi',
     "debug-argument": 'virheenmäärityksen tila',
     "force-gui-prompt-argument": 'aseta asetusilmoite näkyväksi',
     "no-store-argument": "älä säilytä arvoja tiedostossa .syncplay",
     "room-argument": 'vakiohuone',
     "password-argument": 'palvelimen salasana',
     "player-path-argument": 'tiedostopolku toistimen ajettavaan tiedostoon',
     "file-argument": 'tiedosto toistettavaksi',
     "args-argument": 'toisto-ohjelman vaihtoehdot, mikäli tarvitset käyttöön kytkentöjä alkaen - alkuun lisäämiseski yhdellä \'--\' argumentilla',
     "clear-gui-data-argument": 'nollaa tiedostopolun ja ikkunoinnin käyttöliittymätilan joka on taltiotuna kohteeseen QSettings',
     "language-argument": 'kieli Syncplayn viesteille ({})', # Languages

     "version-argument": 'näyttää versiosi',
     "version-message": "Käytät Syncplayn versiota {} ({})",

     "load-playlist-from-file-argument": "lataa toistoluettelon tekstitiedostosta (yksi syöte aina riviä kohti)",


     # Client labels
     "config-window-title": "Syncplayn asetukset",

     "connection-group-title": "Yhteysasetukset",
     "host-label": "Palvelinosoite: ",
     "name-label":  "Käyttäjänimi (valinnainen):",
     "password-label":  "Palvelimen salasana (ei välttämättä mitään):",
     "room-label": "Vakiohuone: ",
     "roomlist-msgbox-label": "Muokkaa huoneluetteloa (yksi aina riviä kohti)",

     "media-setting-title": "Mediatoisto-ohjelman asetukset",
     "executable-path-label": "Tiedostopolku toisto-ohjelmaan:",
     "media-path-label": "Tiedostopolku videoon (valinnainen):",
     "player-arguments-label": "Toistimen määritteet (ei välttämättä mitään):",
     "browse-label": "Selaa",
     "update-server-list-label": "Päivitä luettelo",

     "more-title": "Näytä lisää asetuksia",
     "never-rewind-value": "Ei koskaan",
     "seconds-suffix": " sekuntia",
     "privacy-sendraw-option": "Lähetä raaka",
     "privacy-sendhashed-option": "Lähetä hash-määreellä",
     "privacy-dontsend-option": "Älä lähetä",
     "filename-privacy-label": "Tiedostonimitiedot:",
     "filesize-privacy-label": "Tiedostokokotideot:",
     "checkforupdatesautomatically-label": "Tarkista Syncplayn päivitykset automaattisesti",
     "autosavejoinstolist-label": "Lisää huoneita joihin liityt huoneluetteloon",
     "slowondesync-label": "Hidasta pienen epäyhdennyksen sattuessa (ei tueta MPC-HC/BE:ssä)",
     "rewindondesync-label": "Kelaa taaksepäin mikäli tapahtuu isompi epäyhdennys (suositeltu)",
     "fastforwardondesync-label": "Pikakelaus eteenpäin mikäli toisto laahaa jäljessä (suositeltu)",
     "dontslowdownwithme-label": "Älä koskaan hidasta tai kelaile muita katsojia (kokeellinen)",
     "pausing-title": "Tauotetaan",
     "pauseonleave-label": "Tautota kun käyttäjä poistuu paikalta (esim. jos yhteytensä katkeaa)",
     "readiness-title": "Alustava valmiustila",
     "readyatstart-label": "Aseta minut 'valmiina katselmaan' vakiollisesti",
     "forceguiprompt-label": "Älä näytä Syncplayn asetusikkunaa aina",  # (Inverted)
     "showosd-label": "Kytke päälle OSD-viestit",

     "showosdwarnings-label": "Sisällytä varoitukset (esim. kun tiedostot ovat eroavaiset, käyttäjät eivät valmiina)",
     "showsameroomosd-label": "Sisällytä huoneeseesi tapahtumat",
     "shownoncontrollerosd-label": "Sisällytä tapahtumat ei-hallinnoijilta ylläpidetyissä huoneissa",
     "showdifferentroomosd-label": "Sisällytä tapahtumat muissa huoneissa",
     "showslowdownosd-label": "Sisällytä hidastus / palautus -huomautukset",
     "language-label": "Kieli:",
     "automatic-language": "Vakiollinen ({})",  # Default language
     "showdurationnotification-label": "Varoita median kokonaiskeston eroavaisuuksista",
     "basics-label": "Perusteet",
     "readiness-label": "Toista/tauota",
     "misc-label": "Muut",
     "core-behaviour-title": "Huoneen lähtökohtainen käyttäytymismalli",
     "syncplay-internals-title": "Syncplayn sisäiset ominaisuudet",
     "syncplay-mediasearchdirectories-title": "Hakemistot joista mediaa etsitään",
     "syncplay-mediasearchdirectories-label": "Hakemistot joista mediaa etsitään (yksi polku aina riviä kohti)",
     "sync-label": "Yhdennys",
     "sync-otherslagging-title": "Mikäli muut laahaavat jäljessä...",
     "sync-youlaggging-title": "Mikäli sinä laahaat jäljessä...",
     "messages-label": "Viestit",
     "messages-osd-title": "Näyttöasetukset",
     "messages-other-title": "Muut näyttöasetukset",
     "chat-label": "Keskustelu",
     "privacy-label": "Yksityisyys",  # Currently unused, but will be brought back if more space is needed in Misc tab
     "privacy-title": "Yksityisyysasetukset",
     "unpause-title": "Kun napsautat toista, aseta itsesi valmiiksi ja :",
     "unpause-ifalreadyready-option": "Ota tauotus pois mikäli jo valmiiksi asetettu valmiiksi",
     "unpause-ifothersready-option": "Ota tauotus pois mikäli jo valmis tai muut huoneessa ovat valmiita (vakio)",
     "unpause-ifminusersready-option": "Ota tauotus pois jos jo valmiina tai mikäli kaikki muut valmiita ja vähimmäismäärä käyttäjistä valmiina",
     "unpause-always": "Ota tauotus pois aina",
     "syncplay-trusteddomains-title": "Luotetut palvelimet- ja palvelut (suoratoistopalveluja varten sekä toisaalla isännöidylle sisällölle)",

     "chat-title": "Keskustelun viestisyöte",
     "chatinputenabled-label": "Ota käyttöön keskustelusyöte mpv:n kautta",
     "chatdirectinput-label": "Salli välitön keskustelusyöte (ei tarvetta painaa syöttöpainiketta eli enteriä viestin lähettämiseen)",
     "chatinputfont-label": "Keskustelusyötteen kirjasin",
     "chatfont-label": "Aseta kirjasin",
     "chatcolour-label": "Aseta väri",
     "chatinputposition-label": "Viestisyötteen paikka mpv:ssä",
     "chat-top-option": "Yläosa",
     "chat-middle-option": "Keskellä",
     "chat-bottom-option": "Alaosa",
     "chatoutputheader-label": "Keskusteluviestin ulostulo",
     "chatoutputfont-label": "Keskusteluviestin ulostulon kirjasin",
     "chatoutputenabled-label": "Kytke keskustelun ulostulo mediatoistimessa (vain mpv tällä hetkellä)",
     "chatoutputposition-label": "Ulostulon tyyli",
     "chat-chatroom-option": "Keskusteluhuoneen tyyli",
     "chat-scrolling-option": "Vierityksen tyyli",

     "mpv-key-tab-hint": "[TAB] kytkee pääsyn aakkosrivin avainoikopolkuihin.",
     "mpv-key-hint": "[ENTER] lähettää viestin. [ESC] pois keskustelutilasta.",
     "alphakey-mode-warning-first-line": "Voit väliaikaisesti käyttää vanhoja mpv-sidoksia näppäinhaarukassa a-z.",
     "alphakey-mode-warning-second-line": "Paina [TAB] palateksesi Syncplayn keskustelutilaan.",

     "help-label": "Apu",
     "reset-label": "Palauta vakiot",
     "run-label": "Aja Syncplay",
     "storeandrun-label": "Tallenna asetukset ja aja Syncplay",

     "contact-label": "Voit vapaasti lähettää sähköpostia osoitteeseen <a href=\"mailto:dev@syncplay.pl\"><nobr>dev@syncplay.pl</nobr></a>, <a href=\"https://github.com/Syncplay/syncplay/issues\"><nobr>luo uusi ongelmailmoitus eli issue</nobr></a> ilmoittaaksesi virheen tai muun ongelman GitHub:in kautta, <a href=\"https://github.com/Syncplay/syncplay/discussions\"><nobr>start a discussion</nobr></a> tehdäksesi ehdotuksen tai kysyäksesi kysymyksen GitHub:in kautta, <a href=\"https://www.facebook.com/SyncplaySoftware\"><nobr>tykkää meistä Facebookissa</nobr></a>, <a href=\"https://twitter.com/Syncplay/\"><nobr>seuraa Twitterissä</nobr></a>, tai käy sivullamme <a href=\"https://syncplay.pl/\"><nobr>https://syncplay.pl/</nobr></a>. Älä käytä Syncplay lähettääksesi arkaluontoisia tietoja.",

     "joinroom-label": "Liity huoneeseen",
     "joinroom-menu-label": "Liity huoneeseen {}",
     "seektime-menu-label": "Hakeudu aikajanan kohtaan",
     "undoseek-menu-label": "Peru haku",
     "play-menu-label": "Toista",
     "pause-menu-label": "Tauota",
     "playbackbuttons-menu-label": "Näytä toistopainikkeet",
     "autoplay-menu-label": "Näytä automaattitoiston painike",
     "autoplay-guipushbuttonlabel": "Toista kun kaikki ovat valmiita",
     "autoplay-minimum-label": "Vähimmäinen käyttäjämäärä:",
     "hideemptyrooms-menu-label": "Piilota tyhjät olemassaolevat huoneet",

     "sendmessage-label": "Lähetä",

     "ready-guipushbuttonlabel": "Olen valmis aloittamaan katselemisen!",

     "roomuser-heading-label": "Huone / käyttäjä",
     "size-heading-label": "Koko",
     "duration-heading-label": "Kesto",
     "filename-heading-label": "Tiedostonimi",
     "notifications-heading-label": "Ilmoitteet",
     "userlist-heading-label": "Luettelo kuka toistaa mitäkin",

     "browseformedia-label": "Selaa etsien mediatiedostoja",

     "file-menu-label": "&Tiedosto",  # & precedes shortcut key
     "openmedia-menu-label": "&Avaa mediatiedosto",
     "openstreamurl-menu-label": "Avaa &mediasuoratoiston URL-osoite",
     "setmediadirectories-menu-label": "Aseta median &hakemistot",
     "loadplaylistfromfile-menu-label": "&Lataa toistoluettelo tiedostosta",
     "saveplaylisttofile-menu-label": "&Tallenna toistoluettelo tiedostoon",
     "exit-menu-label": "P&oistu",
     "advanced-menu-label": "&Edistyneet",
     "window-menu-label": "&Ikkuna",
     "setoffset-menu-label": "Aseta &poikkeama",
     "createcontrolledroom-menu-label": "&Luo hallinoitu huone",
     "identifyascontroller-menu-label": "&Tunnistaudu huonevalvojana",
     "settrusteddomains-menu-label": "Aseta &luotetut palvelinosoitteet",
     "addtrusteddomain-menu-label": "Lisää {} luotettuna palvelinosoitteena tai palveluna",  # Domain

     "edit-menu-label": "&Muokkaa",
     "cut-menu-label": "Le&ikkaa",
     "copy-menu-label": "&Kopioi",
     "paste-menu-label": "&Liitä",
     "selectall-menu-label": "&Valitse kaikki",

     "playback-menu-label": "&Toisto",

     "help-menu-label": "&Apu",
     "userguide-menu-label": "Avaa käyttäjän &opas",
     "update-menu-label": "Tarkista &päiviykset",

     "startTLS-initiated": "Koetetaan muodostaa turvattua yhteyttä",
     "startTLS-secure-connection-ok": "Turvattu yhteys muodostettu ({})",
     "startTLS-server-certificate-invalid": 'Turvatun yhteyden muodostaminen ei onnistunut. Kyseessä oleva palvelin käyttää epäkelpoa turvavarmennetta. Tämä yhteydenpito on mahdollista kaapata kolmannen osapuolen toimesta. Lisätietoja- ja ongelmanratkaisua varten katso <a href="https://syncplay.pl/trouble">here</a>.',
     "startTLS-server-certificate-invalid-DNS-ID": "Syncplay ei luota tähän palvelimeen koska se käyttää varmennetta joka ei ole kelvollinen isäntänimeensä nähden.",
     "startTLS-not-supported-client": "Tämä asiakasohjelma ei tue TLS:ää",
     "startTLS-not-supported-server": "Tämä palvelin ei tue TLS:ää",

     # TLS certificate dialog
     "tls-information-title": "Varmenteen yksityiskohdat",
     "tls-dialog-status-label": "<strong>Syncplay käyttää salattua yhteysmallia kohteeseen {}.</strong>",
     "tls-dialog-desc-label": "salaus digitaalisella varmenteella pitää tiedot yksityisinä niitä lähetettäessä palvelimelle <br/>tai palvelimelta{}.",
     "tls-dialog-connection-label": "Tiedot salataan käyttäen Transport Layer Security (TLS), versiota {} jossa on salauksen <br/>sarja: {}.",
     "tls-dialog-certificate-label": "Varmenne julkistettu {} toimesta ajanmukainen kunnes {}.",

     # About dialog
     "about-menu-label": "&Tietoja Syncplay:stä",
     "about-dialog-title": "Tietoja Syncplay:stä",
     "about-dialog-release": "Julkaisu {} release {}",
     "about-dialog-license-text": "Luvitusmalli on Apache&nbsp;License,&nbsp;Version 2.0",
     "about-dialog-license-button": "Lupa",
     "about-dialog-dependencies": "Riippuvaisuudet",

     "setoffset-msgbox-label": "Aseta poikkeama",
     "offsetinfo-msgbox-label": "Poikkeama (katso https://syncplay.pl/guide/ käyttäohjeita varten):",

     "promptforstreamurl-msgbox-label": "Avaa mediasuoratoiston URL-osoite",
     "promptforstreamurlinfo-msgbox-label": "Suoratoiston URL-osoite",

     "addfolder-label": "Lisää kansio",

     "adduris-msgbox-label": "Lisää URL-osoitteet toistoluetteloon (yksi aina riviä kohti)",
     "editplaylist-msgbox-label": "Aseta soittoluettelo (yksi aina riviä kohti)",
     "trusteddomains-msgbox-label": "Palvelinkohteet joihin on sallittua vaihtaa automaattisesti (yksi aina riviä kohti)",

     "createcontrolledroom-msgbox-label": "Luo hallinnoitu huone",
     "controlledroominfo-msgbox-label": "Syötä hallinnoitavan huoneen nimi\r\n(katso https://syncplay.pl/guide/ käyttöohjeita varten):",

     "identifyascontroller-msgbox-label": "Tunnistaudu huonevalvojana",
     "identifyinfo-msgbox-label": "Syötä hallinnoijan salasana tätä huonetta varten\r\n(katso https://syncplay.pl/guide/ käyttöohjeita varten):",

     "public-server-msgbox-label": "Valitse julkispalvelin tätä katseluistuntoa varten",

     "megabyte-suffix": " Mt",

     # Tooltips

     "host-tooltip": "Isäntäpalvelimen nimi tai IP-osoite johon yhistetään, valinnaisesti sisältäen portin (esim. syncplay.pl:8999). Yhdennetään vain ihmisten kanssa jotka samalla palvelimella/portissa.",
     "name-tooltip": "Lempinimi jolla sinun tullaan tuntemaan. Ei rekisteröintiä, joten voit helposti vaihtaa nimen myöhemmin. Luodaan satunnaisnimi ellet syötä mitään.",
     "password-tooltip": "salasanoja tarvitaan vain yhdistäessä yksityispalvelimille.",
     "room-tooltip": "Huone johon liitytään yhdistämisen jälkeen voi olla lähes mitä tahansa, mutta sinut yhdennetään katselussa vain samassa huoneessa olevien ihmisten kanssa.",

     "edit-rooms-tooltip": "Muokkaa huoneluetteloa.",

     "executable-path-tooltip": "Kohde valitsemallesi median toisto-ohjelmalle (mpv, mpv.net, VLC, MPC-HC/BE, mplayer2 tai IINA).",
     "media-path-tooltip": "Avattavan videon sijainti. Välttämätön määrittää mplayer2:n kohdalla.",
     "player-arguments-tooltip": "Komentokehotteen lisävivut- ja käskyt / vivut jotka toimitetaan eteenpäin tälle median toisto-ohjelmalle.",
     "mediasearcdirectories-arguments-tooltip": "Hakemistot joista Syncplay tulee etsimään mediatiedostoja, esim. kun käytät ""napsautuksella vaihto"" -ominaisuutta. Syncplay etsii läpi alikansioidenkin tuon kansion kautta.",

    "more-tooltip": "Näytä harvemminkäytetyt asetukset.",
    "filename-privacy-tooltip": "Yksityisyystila lähetettäessä sillä hetkellä toistetun tiedoston nimeä palvelimelle.",
    "filesize-privacy-tooltip": "Yksityisyystila lähetettäessä sillä hetkellä toistetun tiedoston koko palvelimelle.",
    "privacy-sendraw-tooltip": "Lähetä tuo tieto ilman peittoa. Tämä on vakiollinen tapa joka suo sujuvimman toiminnallisuuden.",
    "privacy-sendhashed-tooltip": "Lähetä hash-määreellinen tietoversio, tehden sen vähemmän näkyväksi muille asiakasohjelmille.",
    "privacy-dontsend-tooltip": "Älä lähetä tätä tietoa palvelimelle. Tämä tarjoaa enimmäisen yksityisyyden.",
    "checkforupdatesautomatically-tooltip": "Tarkista säännöllisesti Syncplayn verkkosivusto josko Syncplayn uusi julkaisu olisi saatavilla.",
    "autosavejoinstolist-tooltip": "Liittyessäsi huoneeseen palvelimella, muista huoneen nimi automaattisesi liityttävien huoneiden luettelossa.",
    "slowondesync-tooltip": "Vähennä toiston astetta väliaikaisesti kun yhtenevyys tarvitsee uudelleenkohdistaa muiden katselijoiden kanssa. Ei tuettu MPC-HC/BE:ssä.",
    "dontslowdownwithme-tooltip": "Tarkoitten että muut eivät koe hidastumista tai taaksepäin kelaamista mikäli oma toistosi laahaa perässä. Kätevä huonevalvojille.",
    "pauseonleave-tooltip": "Tauota toisto mikäli yhteytesi katkeaa tai joku poistuu huoneestasi.",
    "readyatstart-tooltip": "Aseta itsesi tilaan 'valmis' käynnistyksessä (muutoin näyt 'ei valmiina' kunnes muutat valmiustilaasi)",
    "forceguiprompt-tooltip": "Asetusten ilmoitetta ei näytetä kun tiedostoa avataan Syncplayllä.",  # (Inverted)
    "nostore-tooltip": "Aja Syncplay annetulla asetuskokonaisuudella, mutta älä säilö muutoksia pysyvästi.",  # (Inverted)
    "rewindondesync-tooltip": "Hyppää takaisin mikäli näin on tarpeellinen tehdä päästäksesi takaisin ajallisesti katselussa yhdentyneeksi. Tämän valinnan poiskytkeminen voi johtaa hyvin suuriin yhdentämisen eroavaisuuksiin ja katsotte toistoa aivan eri kohdissa!",
    "fastforwardondesync-tooltip": "Hyppää eteenpäin kun yhdentäminen on katkennut huonevalvojan kanssa (tai teeskennnyskohdan suhteen jos 'älä hidasta koskaan- tai taaksepäin kelaa muita' on kytkettynä).",
    "showosd-tooltip": "Lähettää Syncplay-viestejä mediatoistimen OSD:hen.",
    "showosdwarnings-tooltip": "Näytä varoitukset mikäli toistossa on eri tiedosto, yksin huoneessa, tai käyttäjät eivät valmiina, jne.",
    "showsameroomosd-tooltip": "Näytä OSD-ilmoitteet tapahtumille liittyen huoneeseen jossa käyttäjä on.",
    "shownoncontrollerosd-tooltip": "Näytä OSD-ilmoitteet tapahtumille liittyen ei-huonevalvojiin jotka ovat hallinnoiduissa huoneissa.",
    "showdifferentroomosd-tooltip": "Näytä OSD-ilmoitteet tapahtumille liittyen huoneeseen jossa käyttäjä ei ole.",
    "showslowdownosd-tooltip": "Näytä ilmoitteet hidastamisesta / palautuksesta aikaeroavaisuuden takia.",
    "showdurationnotification-tooltip": "Hyödylinen silloin kun osio moniosaisen tiedoston suhteen uupuu, mutta voi tuottaa vääriä ilmoitusarvoja.",
    "language-tooltip": "Kieli jota käytetään Syncplayssä.",
    "unpause-always-tooltip": "Mikäli painat 'tauko pois' asettaa se toimi sinut aina valmiiksi ja tauon pois päältä, sen sijaan että näyt vain 'valmiina'.",
    "unpause-ifalreadyready-tooltip": "Mikäli painat tauon pois kun et valmis se asettaa sinut kuitenkin valmiiksi - paina tauko pois uudelleen jatkaaksesi toistoa.",
    "unpause-ifothersready-tooltip": "Mikäli painat tauon pois kun et valmis, se tauottaa ainoastaan jos muut ovat valmiina.",
    "unpause-ifminusersready-tooltip": "Mikäli painat tauon pois kun et valmiina, se ottaa tauon pois vain jos muut ovat valmiina ja vähimmäismäärä käyttäjiä on täytetty.",
    "trusteddomains-arguments-tooltip": "Palvelimet- ja palvelut jotka ovat sallittuja vaihtaa käyttöön automaattisesti Syncplayssä kun jaetut toistoluettelot on kytketty käyttöön.",

    "chatinputenabled-tooltip": "Kytke päälle keskustelusyöte mpv:ssä (paina syöttönäppäintä eli enter keskustellaksesi, tuota samaa näppäintä lähettääksesi viestin, Esc -painiketta keskeyttääksesi)",
    "chatdirectinput-tooltip": "Ohita tuon syöttänäppäimen eli 'enter' painallustarve ja siirry suoraan syöttötilaan mpv:ssä. Paina TAB mpv:ssä kytkeäksesi väliaikaisesti tämän ominaisuuden pois päältä.",
    "font-label-tooltip": "Kirjasintyyli jota käytetään lähettäessä keskusteluviestejä mpv:ssä. Vain asiakasohjelmapuoli pätee tässä, joten ei vaikuta siihen mitä muut näkevät.",
    "set-input-font-tooltip": "Kirjasinperhe jota käytetään syötettäessä viestejä mpv:ssä. Vain asiakasohjelmapuoli pätee tässä, joten ei vaikuta siihen mitä muut näkevät.",
    "set-input-colour-tooltip": "Kirjasimen väri jota käytetään syötettäessä viestejä mpv:ssä. Vain asiakasohjelmapuoli pätee tässä, joten ei vaikuta siihen mitä muut näkevät.",
    "chatinputposition-tooltip": "Sijainti mpv-toistimessa missä keskusteluviestit näkyvät kun painat syötepainiketta eli enteriä ja kirjoitat.",
    "chatinputposition-top-tooltip": "Aseta keskustelusyöte mpv-ikkunan yläosaan.",
    "chatinputposition-middle-tooltip": "Aseta keskustelusyöte mpv-ikkunan keskelle.",
    "chatinputposition-bottom-tooltip": "Aseta keksustelusyöte mpv-ikkunan alaosaan.",
    "chatoutputenabled-tooltip": "Näytä keskusteluviestit OSD:ssä (mikäli mediatoistin tätä tukee).",
    "font-output-label-tooltip": "Keksustelun ulosmeno kirjasin.",
    "set-output-font-tooltip": "Kirjasin jota käytetään tulostaessa keskusteluviestejä näytölle.",
    "chatoutputmode-tooltip": "Miten keskusteluviestit näytetään.",
    "chatoutputmode-chatroom-tooltip": "Näytä uusia keskustelun rivejä suoraan edellisen rivin alle.",
    "chatoutputmode-scrolling-tooltip": "Rullaa keskustelutekstiä oikealta vasemmalle.",

    "help-tooltip": "Avaa Syncplay.pl:n käyttöohjeen.",
    "reset-tooltip": "Nollaa kaikki asetukset niiden vakiolliseen lähtökohtaan.",
    "update-server-list-tooltip": "Yhdistä syncplay.pl:ään julkisten palvelinten luettelon päivittämiseksi.",

    "sslconnection-tooltip": "Yhteys muodostettu turvallisesti palvelimeen. Napsauta varmennetta saadaksesi yksityiskohtaista tietoa.",

    "joinroom-tooltip": "Poistuu nykyisestä huoneesta ja liittyy määriteltyyn huoneeseen.",
    "seektime-msgbox-label": "Hyppää määriteltyyn aikakohtaan (sekunneissa / min:sek). Käytä painikkeita +/- hakeaksesi edelleen tarkemmin kohtaa.",
    "ready-tooltip": "Osoittaa oletko valmiina aloittamaan katselemisen.",
    "autoplay-tooltip": "Toista automaattisesti kun kaikki käyttäjät joilla on valmiusilmaisin osoittamassa 'valmis' ja vähimmäinen käyttäjämäärä on saavutettu.",
    "switch-to-file-tooltip": "Kaksoisnapsauta vaihtaaksesi kohteeseen {}",  # Filename
    "sendmessage-tooltip": "Lähetä viesti huoneeseen",

    # In-userlist notes (GUI)
    "differentsize-note": "Eroava koko!",
    "differentsizeandduration-note": "Eroava koko ja kesto!",
    "differentduration-note": "Eroava kesto!",
    "nofile-note": "(Mitään tiedostoa ei ole toistossa)",

    # Server messages to client
    "new-syncplay-available-motd-message": "Käytät Syncplay:tä {} mutta uudempi julkaisu on tarjolla osoitteessa https://syncplay.pl",  # ClientVersion
    "persistent-rooms-notice": "HUOMIO: Tämä palvelin käyttää pysyviä huoneita, joka tarkoittaa, että toistoluettelojen tieto taltioidaan toistoistuntojen välillä. Mikäli halkuat luoda huoneen jossa tietoja ei tallenneta, laita vipu -temp huoneen nimen perään.", # NOTE: Do not translate the word -temp
    "ready-chat-message": "I have set {} as ready.",  # User # TODO: Translate
    "not-ready-chat-message": "I have set {} as not ready.",  # User # TODO: Translate

    # Server notifications
    "welcome-server-notification": "Tervetuloa Syncplay-palvelimelle, ver. {0}",  # version
    "client-connected-room-server-notification": "{0}({2}) yhteydessä huoneeseen '{1}'",  # username, host, room
    "client-left-server-notification": "{0} poistui palvelimelta",  # name
    "no-salt-notification": "HUOMAATHAN: salliaksesi huonevalvojan salasanoja muodostettavaksi tällä palvelimella ja niiden toimiakseen myös kun palvelin uudelleenkäynnistetään, lisääthän seuraavan kaksoisvivun kun ajat Syncplaytä tällä palvelimella tulevaisuudessa: --salt {}",  # Salt


    # Server arguments
    "server-argument-description": 'Ratkaisu toiston yhdentämiseen useiden mediatoistinten kanssa verkon yli. Palvelin',
    "server-argument-epilog": 'Mikäli vaihtoehtoja ei määritetä käytetään _config arvoja',
    "server-port-argument": 'palvelimen TCP-port',
    "server-password-argument": 'palvelimen salasana',
    "server-isolate-room-argument": 'eristetäänkö huoneet?',
    "server-salt-argument": "satunnaislanka jota käytetään luodakseen hallinnoitujen huoneiden salasanoja",
    "server-disable-ready-argument": "poista käytöstä valmiusominaisuus",
    "server-motd-argument": "tiedostopolku tiedostoon josta motd noudetaan",
    "server-rooms-argument": "polku tietokantatiedostoon jota käytetään tai jos pysyväishuoneen dataa varten. Kytkee päälle huoneiden pysyvyyden ilman katsojia ja säilyvyys pysyy uudelleenkäynnistysenkin jälkeen",
    "server-permanent-rooms-argument": "polku tiedostoon joka luetteloi pysyvät huoneet jotka luetteloidaan vaikka huone olisi tyhjäkin (tekstitiedostomuodossa joka luetteloi joka luetteloi yhden huoneen aina riviä kohden) - vaatii pysyvien huoneiden -toiminnon päällekytkennän",
    "server-chat-argument": "Kytketäänkö keskustelu pois päältä?",
    "server-chat-maxchars-argument": "Merkkien enimmäismäärä keskusteluviestissä (vakio on {})", # Default number of characters
    "server-maxusernamelength-argument": "Merkkien enimmäismäärä käyttäjänimessä (vakio on {})",
    "server-stats-db-file-argument": "Kytke päälle palvelintilastot käyttäen toimitettua SQLite db -tiedostoa",
    "server-startTLS-argument": "Kytke päälle TLS-yhteydet käyttäen varmennetiedostoja annetun tiedostopolkun kautta",
    "server-messed-up-motd-unescaped-placeholders": "Päivän viestissä on epäkelvot paikkamerkit. Kaikki $ merkit tulisi kaksinaistaa ($$).",
    "server-messed-up-motd-too-long": "Päivän viesti on liian pitkä - enimmäispituus on {} merkkiä, {} annettu.",

    # Server errors
    "unknown-command-server-error": "Tuntematon käsky {}",  # message
    "not-json-server-error": "Tämä ei ole json-enkoodattu käskyjono {}",  # message
    "line-decode-server-error": "Tämä ei ole utf-8 -lanka",
    "not-known-server-error": "Palvelimen tulee tuntea sinut ensinnä ennen kuin voit lähettää tämän käskyn",
    "client-drop-server-error": "Asiakasohjelman pudotus: {} -- {}",  # host, error
    "password-required-server-error": "Salasana on vaadittu",
    "wrong-password-server-error": "Toimitit väärän salasanan",
    "hello-server-error": "Not enough Hello arguments",  # DO NOT TRANSLATE

    # Playlists
    "playlist-selection-changed-notification":  "{} toistoluettelon valintoja muutettiin",  # Username
    "playlist-contents-changed-notification": "{} toistoluettelo päivitettiin",  # Username
    "cannot-find-file-for-playlist-switch-error": "Tiedostoa {} ei löytynyt mediahakemistoista toistoluettelon vaihtoa varten!",  # Filename
    "cannot-add-duplicate-error": "Toisarvoista kohdetta ei saatu lisättyä '{}' toistoluetteloon koska kaksoiskappaleita ei sallita.",  # Filename
    "cannot-add-unsafe-path-error": "Ei voitu ladata automaattisesti kohdetta {} koska se ei ole luotettu. Voit vaihtaa URL-osoitteen käsin kaksoisnapsauttamalla sitä toistoluettelossa, ja sitten vain lisäät luotetut palvelimet valikosta Tiedosto ->Edistyneet->Aseta luotetut palvelimet. Mikäli napsautat hiiren oikealla napilla URL-osoitteessa voit täten asettaa sen luotetuksi aihevalikon kautta.",  # Filename
    "sharedplaylistenabled-label": "Kytke jaetut toistoluettelot käyttöön",
    "removefromplaylist-menu-label": "Poista toistoluettelosta",
    "shuffleremainingplaylist-menu-label": "Sekoita jäljellä oleva toistoluettelosisältö",
    "shuffleentireplaylist-menu-label": "Sekoita koko toistoluettelo",
    "undoplaylist-menu-label": "Kumoa toistoluettelon viime muutos",
    "addfilestoplaylist-menu-label": "Lisää tiedosto(t) toistoluettelon alaosaan",
    "addurlstoplaylist-menu-label": "Lisää URL-osoite(tai osoitteet) toistoluettelon alaosaan",
    "editplaylist-menu-label": "Muokkaa toistoluetteloa",

    "open-containing-folder": "Avaa kansio jossa tämä tiedosto sijaitsee",
    "addyourfiletoplaylist-menu-label": "Lisää tiedostosi toistoluetteloon",
    "addotherusersfiletoplaylist-menu-label": "Lisää {}'n tiedosto toistoluetteloon",  # [Username]
    "addyourstreamstoplaylist-menu-label": "Lisää suoratoistosi toistoluetteloon",
    "addotherusersstreamstoplaylist-menu-label": "Lisää {}'n suoratoisto toistoluetteloon",  # [Username]
    "openusersstream-menu-label": "Avaa {}'n suoratoisto",  # [username]'s
    "openusersfile-menu-label": "Avaa {}'n tiedosto",  # [username]'s

    "setasready-menu-label": "Set {} as ready",  # [Username] # TODO: Translate
    "setasnotready-menu-label": "Set {} as not ready",  # [Username] # TODO: Translate

    "playlist-instruction-item-message": "Raahaa tiedosto tähän lisätäksesi sen jaettuun toistoluetteloon.",
    "sharedplaylistenabled-tooltip": "Huonevalvojat voivat lisätä tiedostoja yhdennettävään toistoluetteloon tehdäkseen kaikille helpoksi katsoa samaa asiaa. Määritä mediahakemistot kohteen 'Muut' alta.",

    "playlist-empty-error": "Toistoluettelo on tällä hetkellä tyhjä.",
    "playlist-invalid-index-error": "Epäkelpo toistoluettelohakemisto",
}


# coding:utf8

"""Esperanto dictionary"""

# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN

# Komentoj kun tradukistaj notoj komenciĝas per «FARU:».

eo = {
    "LANGUAGE": "Esperanto",
    "LANGUAGE-TAG": "eo",

    # Strings for Windows NSIS installer
    "installer-language-file": "Esperanto.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
    "installer-associate": "Asocii vidaŭdaĵajn dosierojn kun Syncplay.",
    "installer-shortcut": "Krei mallongigojn en la jenaj lokoj:",
    "installer-start-menu": "Start-menuo",
    "installer-desktop": "Labortablo",
    "installer-quick-launch-bar": "Tujbreto",
    "installer-automatic-updates": "Kontroli ĝisdatigojn memage",
    "installer-uninstall-configuration": "Forigi dosieron kun agordaro.",

    # Client notifications
    "config-cleared-notification": "Agordoj vakiĝis. Ŝanĝoj konserviĝos kiam vi enmemorigos validan agordaron.",

    "relative-config-notification": "Enlegis rilatajn agordajn dosierojn: {}", # FARU: originale «relative» – ĉu «rilataj»?

    "connection-attempt-notification": "Provas konektiĝi al {}:{}",  # Port, IP
    "reconnection-attempt-notification": "Konekto al servilo perdiĝis; provas rekonektiĝi",
    "disconnection-notification": "Malkonektiĝis de servilo",
    "connection-failed-notification": "Konekto al servilo malsukcesis",
    "connected-successful-notification": "Sukcese konektiĝis al servilo",
    "retrying-notification": "%s, reprovos post %d sekundoj…",  # Seconds
    "reachout-successful-notification": "Sukcese atingis al {} ({})",

    "rewind-notification": "Reiris pro tempa malakordo kun {}",  # User
    "fastforward-notification": "Pluiris pro tempa malakordo kun {}",  # User
    "slowdown-notification": "Malrapidiĝas pro tempa malakordo kun {}",  # User
    "revert-notification": "Rerapidiĝas",

    "pause-notification": "{} paŭzigis je {}",  # User, Time
    "unpause-notification": "{} malpaŭzigis",  # User
    "seek-notification": "{} saltis de {} al {}",  # User, from time, to time

    "current-offset-notification": "Nuna frueco: {} sekundoj",  # Offset

    "media-directory-list-updated-notification": "Dosierujoj kun vidaŭdaĵoj por Syncplay ĝisdatiĝis.",

    "room-join-notification": "{} aliĝis al ĉambro: «{}»",  # User
    "left-notification": "{} foriris",  # User
    "left-paused-notification": "{} foriris, {} paŭzigis",  # User who left, User who paused
    "playing-notification": "{} ludas dosieron «{}» ({})",  # User, file, duration
    "playing-notification/room-addendum": " en ĉambro: «{}»",  # Room

    "not-all-ready": "Ne pretas: {}",  # Usernames
    "all-users-ready": "Ĉiuj pretas ({} uzantoj)",  # Number of ready users
    "ready-to-unpause-notification": "Nun vi estas markita preta – malpaŭzigu ree por vere malpaŭzigi",
    "set-as-ready-notification": "Nun vi estas markita preta",
    "set-as-not-ready-notification": "Nun vi estas markita nepreta",
    "autoplaying-notification": "Memage ludos post {}…",  # Number of seconds until playback will start

    "identifying-as-controller-notification": "Identiĝas kiel ĉambrestro per la pasvorto «{}»...",
    "failed-to-identify-as-controller-notification": "{} malsukcesis identiĝi ĉambrestro.",
    "authenticated-as-controller-notification": "{} identiĝis ĉambrestro",
    "created-controlled-room-notification": "Kreis estratan ĉambron «{}» kun pasvorto «{}». Bonvolu konservi tiujn informojn osen!\n\nEn estrataj ĉambroj, ĉiu spegulas la ĉambrestrojn, kiuj estas la solaj, kiuj povas paŭzigi, malpaŭzigi, iri, kaj ŝanĝi la ludliston.\n\nVi petu ordinarajn spektantojn aliĝi la ĉambron «{}», sed ĉambrestroj povas aliĝi la ĉambron «{}» por memage aŭtentikiĝi.",  # RoomName, operatorPassword, roomName, roomName:operatorPassword

    "other-set-as-ready-notification": "{} was set as ready by {}",  # User set as ready, user who set them as ready # TODO: Translate
    "other-set-as-not-ready-notification": "{} was set as not ready by {}", # User set as not ready, user who set them as not ready # TODO: Translate

    "file-different-notification": "La dosiero, kiun vi ludas, ŝajnas malsama de tiu de {}",  # User
    "file-differences-notification": "Via dosiero malsamas per ĉi tiuj manieroj: {}",  # Differences
    "room-file-differences": "Malsamoj inter dosieroj: {}",  # File differences (filename, size, and/or duration)
    "file-difference-filename": "nomo",
    "file-difference-filesize": "grandeco",
    "file-difference-duration": "daŭro",
    "alone-in-the-room": "Vi estas sola en la ĉambro",

    "different-filesize-notification": " (grandeco de ĝia dosiero malsamas de tiu de la via!)",
    "userlist-playing-notification": "{} ludas:",  # Username
    "file-played-by-notification": "Dosiero: {} estas ludata de:",  # File
    "no-file-played-notification": "{} ne ludas dosieron nun",  # Username
    "notplaying-notification": "Homoj, kiuj ne ludas iun dosieron nun:",
    "userlist-room-notification":  "En ĉambro «{}»:",  # Room
    "userlist-file-notification": "Dosiero",
    "controller-userlist-userflag": "Ĉambrestro",
    "ready-userlist-userflag": "Preta",

    "update-check-failed-notification": "Ne povis memage kontroli, ĉu Syncplay {} estas ĝisdata. Ĉu vi volus viziti al https://syncplay.pl/ kaj kontroli permane?",  # Syncplay version
    "syncplay-uptodate-notification": "Syncplay estas ĝisdata",
    "syncplay-updateavailable-notification": "Nova versio de Syncplay disponeblas. Ĉu vi volus viziti la eldonan paĝon?",

    "mplayer-file-required-notification": "Syncplay kun mplayer bezonas dosieron je starto",
    "mplayer-file-required-notification/example": "Ekzempla uzo: syncplay [elektoj] [url|vojo/]dosiernomo",
    "mplayer2-required": "Syncplay ne akordas kun MPlayer 1.x, bonvolu uzi programojn mplayer2 aŭ mpv",

    "unrecognized-command-notification": "Nerekonita ordono",
    "commandlist-notification": "Doneblaj ordonoj:",
    "commandlist-notification/room": "\tr [nomo] – ŝanĝi ĉambron",
    "commandlist-notification/list": "\tl – montri liston de uzantoj",
    "commandlist-notification/undo": "\tu – maliri",
    "commandlist-notification/pause": "\tp – (mal)paŭzigi",
    "commandlist-notification/seek": "\t[s][+-]tempo - iri al donita tempo; se + aŭ - ne estas donita, ĝi estu absoluta tempo en sekundoj aŭ minutoj:sekundoj",
    "commandlist-notification/offset": "\to[+-]daŭro - fruigi lokan ludadon je la donita daŭro (en sekundoj aŭ minutoj:sekundoj), kompare al la servila pozicio – ĉi tiu kapablo ne plu estos subtenata",
    "commandlist-notification/help": "\th – tiu ĉi helpilo",
    "commandlist-notification/toggle": "\tt – ŝanĝas ĉu vi pretas spekti aŭ ne",
    "commandlist-notification/setready": "\tsr [name] - sets user as ready",  # TODO: Translate
    "commandlist-notification/setnotready": "\tsn [name] - sets user as not ready",  # TODO: Translate
    "commandlist-notification/create": "\tc [nomo] – krei estratan ĉambron kun nomo de la nuna ĉambro",
    "commandlist-notification/auth": "\ta [pasvorto] – aŭtentikiĝi ĉambrestro per ĉambrestra pasvorto",
    "commandlist-notification/chat": "\tch [mesaĝo] – sendi babilan mesaĝon al ĉambro",
    "commandList-notification/queue": "\tqa [dosiero/url] – aldoni dosieron aŭ URL-on fine de ludlisto",
    "commandList-notification/queueandselect": "\tqas [dosiero/url] – aldoni dosieron aŭ URL-on fine de ludlisto, kaj ĝin elekti",
    "commandList-notification/playlist": "\tql – montri la nunan ludliston",
    "commandList-notification/select": "\tqs [index] – elekti donitan ludlisteron",
    "commandList-notification/next": "\tqn – elekti sekvantan ludlisteron",
    "commandList-notification/delete": "\tqd [index] – forigi la donitan ludlisteron de la ludlisto",
    "syncplay-version-notification": "Versio de Syncplay: {}",  # syncplay.version
    "more-info-notification": "Pliaj informoj disponeblas per: {}",  # projectURL

    "gui-data-cleared-notification": "Syncplay vakigis la vojon kaj fenestrajn datumojn uzatajn de la fasado.",
    "language-changed-msgbox-label": "Lingvo ŝanĝiĝos kiam Syncplay ruliĝos refoje.",
    "promptforupdate-label": "Ĉu Syncplay rajtas memage kontroli fojfoje, ĉu disponeblas ĝisdatigoj?",

    "media-player-latency-warning": "Averto: La vidaŭdaĵa ludilo respondis post {} sekundoj. Se vi havos problemojn pri vidaŭdaĵa spegulado, fermu iujn aplikaĵojn por liberigi rimedojn de la sistemo, kaj se tio ne funkcios, provu alian vidaŭdaĵan ludilon.",  # Seconds to respond
    "mpv-unresponsive-error": "mpv ne respondis dum {} sekundoj, do eble ne funkcias. Bonvolu reruli on Syncplay.",  # Seconds to respond

    # Client prompts
    "enter-to-exit-prompt": "Premu enigan klavon por ĉesigi\n",

    # Client errors
    "missing-arguments-error": "Iuj gravaj parametroj mankas, vidu je --help",
    "server-timeout-error": "Konekto al servilo eltempiĝis",
    "mpc-slave-error": "MPC ne povas nun starti en sklava reĝimo!",
    "mpc-version-insufficient-error": "Versio de MPC ne sufiĉas, bonvolu uzi `mpc-hc` ≥ `{}`",
    "mpc-be-version-insufficient-error": "Versio de MPC ne sufiĉas, bonvolu uzi `mpc-be` ≥ `{}`",
    "mpv-version-error": "Syncplay ne akordas ĉi tiun version de mpv. Bonvolu uzi alian version de mpv (ekz. Git HEAD).",
    "mpv-failed-advice": "The reason mpv cannot start may be due to the use of unsupported command line arguments or an unsupported version of mpv.",
    "mpv-failed-advice": "Eble mpv ne povas starti pro nesubtenataj konzolaj parametroj, aŭ nesubtenata versio de mpv.", # FARU: «konzolaj» – ĉu bona traduko de «command-line»?
    "player-file-open-error": "Ludilo malsukcesis malfermi dosieron",
    "player-path-error": "Vojo al ludilo ne estas ĝuste agordita. Nun subtenataj ludiloj estas: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2, kaj IINA",
    "hostname-empty-error": "Nomo de gastiga komputilo ne povas esti malplena",
    "empty-error": "{} ne povas esti malplena",  # Configuration
    "media-player-error": "Eraro de vidaŭdaĵa ludilo: \"{}\"",  # Error line
    "unable-import-gui-error": "Ne povis enporti fasadajn bibliotekojn. Se PySide ne estas instalita, vi devos instali ĝin, por ke la fasado funkciu. If you want to run Syncplay in console mode then run it with the --no-gui command line switch. See https://syncplay.pl/guide/ for more details.", # TODO: Translate end of message and update second sentence to be a translation of "You need to have the correct version of PySide installed for the GUI to work."
    "unable-import-twisted-error": "Ne povis enporti la bibliotekon Twisted. Bonvolu instali version 16.4.0 de Twisted, aŭ pli altan.",

    "arguments-missing-error": "Iuj bezonataj parametroj mankas; vidu al --help",

    "unable-to-start-client-error": "Ne povas ruli klienton",

    "player-path-config-error": "Vojo al ludilo ne estas ĝuste agordita. Nun subtenataj ludiloj estas: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2, kaj IINA",
    "no-file-path-config-error": "Dosiero devas esti elektita, antaŭ ol vi rulos vian ludilon", # FARU: eble «komencos» aŭ «ludigos»?
    "no-hostname-config-error": "Nomo de gastiga komputilo ne povas esti malplena",
    "invalid-port-config-error": "Pordo devas esti valida",
    "empty-value-config-error": "{} ne povas esti malplena",  # Config option

    "not-json-error": "Tio ne estas JSON-teksto\n",
    "hello-arguments-error": "Not enough Hello arguments\n",  # DO NOT TRANSLATE # OKAY, OKAY! Geez! No need to shout.
    "version-mismatch-error": "Malakordo inter versioj de kliento kaj servilo\n",
    "vlc-failed-connection": "Malsukcesis konektiĝi al VLC. Se vi ne instalis syncplay.lua, kaj uzas la lastan version de VLC, bonvolu vidi la instrukciojn en https://syncplay.pl/LUA/. Syncplay kaj VLC 4 ne estas interkonformaj nun, do bonvolu uzi VLC 3, aŭ alternativon kiel mpv.",
    "vlc-failed-noscript": "VLC raportis, ke la interfaca skripto syncplay.lua ne estas instalita. Bonvolu vidi instrukciojn en https://syncplay.pl/LUA/",
    "vlc-failed-versioncheck": "Ĉi tiu versio de VLC ne estas subtenata de Syncplay.",
    "vlc-initial-warning": 'VLC ne ĉiam donas precizajn informojn pri pozicio al Syncplay, precipe pri dosierformoj .mp4 kaj .avi. Se vi spertos problemon pri poziciiĝo en filmo, bonvolu provi alternativan vidaŭdaĵan ludilon, kiel ekzemple <a href="https://mpv.io/">mpv</a> (aŭ <a href="https://github.com/stax76/mpv.net/">mpv.net</a> por uzantoj de Vindozo).',

    "feature-sharedPlaylists": "komunaj ludlistoj",  # used for not-supported-by-server-error
    "feature-chat": "babilado",  # used for not-supported-by-server-error
    "feature-readiness": "preteco",  # used for not-supported-by-server-error
    "feature-managedRooms": "estrataj ĉambroj",  # used for not-supported-by-server-error
    "feature-setOthersReadiness": "readiness override",  # used for not-supported-by-server-error # TODO: Translate

    "not-supported-by-server-error": "La kapablo «{}» ne estas subtenata de ĉi tiu servilo.",  # feature
    "shared-playlists-not-supported-by-server-error": "La servilo eble ne subtenas komunajn ludlistojn. Ĝusta funkciado postulas servilon kun Syncplay {}+, sed la servilo havas nur version {}.",  # minVersion, serverVersion
    "shared-playlists-disabled-by-server-error": "Komunaj ludlistoj estas malŝaltitaj en la servila agordaro. Por uzi ĉi tiun kapablon, vi devos konektiĝi al alia servilo.",

    "invalid-seek-value": "Nevalida valoro de iro",
    "invalid-offset-value": "Nevalida valoro de frueco",

    "switch-file-not-found-error": "Ne povis ŝalti dosieron «{0}». Syncplay serĉas en donitaj dosierujoj kun vidaŭdaĵoj.",  # File not found
    "folder-search-timeout-error": "La serĉado de vidaŭdaĵoj en dosierujoj kun vidaŭdaĵoj haltis, ĉar serĉado en «{}» postulis tro da tempo (after having processed the first {:,} files). Ĉi tio okazos, se vi elektos dosierujon kun tro multaj subdosierujoj en via listo de enserĉotaj dosierujoj kun vidaŭdaĵoj. Por refunkciigi memagan ŝaltadon de dosieroj, bonvolu elekti menueron «Dosiero → Agordi dosierujojn kun vidaŭdaĵoj» en la menubreto, kaj forigi ĉi tiun dosierujon, aŭ anstataŭigi ĝin per taŭga sub-dosierujo. Se vi trovos, ke la dosierujo fakte funkcias bone, vi povos reŝalti ĝin per «Dosiero → Agordi dosierujojn kun vidaŭdaĵoj» kaj klako al «Bone».",  # Folder, Files processed - Note: {:,} is {} but with added commas seprators - TODO: Translate
    "folder-search-timeout-warning": "Warning: It has taken {} seconds to scan {:,} files in the folder '{}'. This will occur if you select a folder with too many sub-folders in your list of media folders to search through or if there are too many files to process.",  # Folder, Files processed. Note: {:,} is {} but with added commas seprators. TODO: Translate
    "folder-search-first-file-timeout-error": "La serĉo de vidaŭdaĵoj en «{}» haltis, ĉar aliro al la dosierujo postulis tro da tempo. Ĉi tio povas okazi se ĝi estas reta disko aŭ se vi agordis vian diskon malrapidiĝi post neaktivado. Por ke funkciu memaga ŝanĝado de dosieroj, bonvolu iri al «Dosiero → Agordi vidaŭdaĵajn dosierujojn», kaj forigu la dosierujon, aŭ solvu la problemon (ekz. per ŝanĝo de viaj agordoj por konservado de elektro).",  # Folder
    "added-file-not-in-media-directory-error": "Vi enlegis dosieron el «{}», kiu ne estas konata vidaŭdaĵa dosierujo. Vi povas aldoni ĝin al vidaŭdaĵaj dosierujoj per la menuero «Dosiero → Agordi vidaŭdaĵajn dosierujojn» en la menua breto.",  # Folder
    "no-media-directories-error": "Neniuj vidaŭdaĵaj dosierujoj estas agorditaj. Por ke kapabloj de komunaj ludlistoj kaj ŝanĝado de dosieroj funkciu ĝuste, bonvolu elekti menueron «Dosiero → Agordi vidaŭdaĵajn dosierujojn», kaj precizigu, kie Syncplay serĉu vidaŭdaĵojn.",
    "cannot-find-directory-error": "Ne povis trovi vidaŭdaĵan dosierujon «{}». Por ĝisdatigi vian liston de vidaŭdaĵaj dosierujoj, bonvolu elekti menueron «Dosiero → Agordi vidaŭdaĵajn dosierujojn» en la menubreto, kaj precizigi, kie Syncplay serĉu vidaŭdaĵojn.",

    "failed-to-load-server-list-error": "Malsukcesis enlegi liston de publikaj serviloj. Bonvolu viziti al https://www.syncplay.pl/ per via reta foliumilo.",

    # Client arguments
    "argument-description": 'Rimedo samtempigi plurajn vidaŭdaĵajn ludilojn per la reto.',
    "argument-epilog": 'Se neniuj elektoj estos donitaj, uziĝos valoroj de _config',
    "nogui-argument": 'ne montri fasadon',
    "host-argument": "adreso de servilo",
    "name-argument": 'dezirata uzantonomo',
    "debug-argument": 'erarserĉa reĝimo',
    "force-gui-prompt-argument": 'montru agordan fenestron',
    "no-store-argument": "ne konservu valorojn en .syncplay",
    "room-argument": 'implicita ĉambro',
    "password-argument": 'pasvorto de servilo',
    "player-path-argument": 'vojo al rulaĵo de via vidaŭdaĵa ludilo',
    "file-argument": 'ludota dosiero',
    "args-argument": 'agordoj de ludilo; se vi bezonas doni elektojn, kiuj komenciĝas per «-», antaŭmetu solan parametron «--»',
    "clear-gui-data-argument": 'restarigas vojon kaj datumojn pri stato de la fenestro, konservitajn en la formo [QSettings]',
    "language-argument": 'lingvo por mesaĝoj de Syncplay ({})', # Languages

    "version-argument": 'presas vian version',
    "version-message": "Vi uzas programon Syncplay, versio {} ({})",

    "load-playlist-from-file-argument": "legas ludliston de teksta dosiero (po unu listero linie)",


    # Client labels
    "config-window-title": "Agordaro de Syncplay",

    "connection-group-title": "Agordoj de konekto",
    "host-label": "Adreso de servilo: ",
    "name-label":  "Uzantonomo (nenecesa):",
    "password-label":  "Pasvorto de servilo (se ekzistas):",
    "room-label": "Komenca ĉambro: ",
    "roomlist-msgbox-label": "Redakti liston de ĉambroj (po unu ĉambro linie)",

    "media-setting-title": "Agordoj de vidaŭdaĵa ludilo",
    "executable-path-label": "Vojo al vidaŭdaĵa ludilo:",
    "media-path-label": "Vojo al filmo:",
    "player-arguments-label": "Parametroj de ludilo (se ekzistas):",
    "browse-label": "Foliumi",
    "update-server-list-label": "Ĝisdatigi liston",

    "more-title": "Montri pliajn agordojn",
    "never-rewind-value": "Neniam",
    "seconds-suffix": " sekundoj",
    "privacy-sendraw-option": "Sendi krude",
    "privacy-sendhashed-option": "Sendi hakete",
    "privacy-dontsend-option": "Ne sendi",
    "filename-privacy-label": "Informo pri dosiernomo:",
    "filesize-privacy-label": "Informo pri dosiergrandeco:",
    "checkforupdatesautomatically-label": "Memage kontroli ĝisdatigojn de Syncplay",
    "autosavejoinstolist-label": "Aldoni aliĝitajn ĉambrojn al la listo de ĉambroj",
    "slowondesync-label": "Malrapidiĝi pro eta malakordo (ne disponeblas por MPC-HC/BE)",
    "rewindondesync-label": "Reiri pro ega malakordo (rekomendata)",
    "fastforwardondesync-label": "Pluiri pro malfrueco (rekomendata)",
    "dontslowdownwithme-label": "Neniam malrapidigi nek reirigi aliulojn (eksperimenta)",
    "pausing-title": "Paŭzado",
    "pauseonleave-label": "Paŭzigi kiam uzanto foriras (ekz. se ĝi malkonektiĝis)",
    "readiness-title": "Komenca preteco",
    "readyatstart-label": "Marki min «preta spekti» dekomence",
    "forceguiprompt-label": "Ne montru ĉiam la agordan fenestron de Syncplay",  # (Inverted)
    "showosd-label": "Ŝalti mesaĝojn en fasado",

    "showosdwarnings-label": "Inkluzivi avertojn (ekz. kiam dosieroj malsamas, uzantoj ne pretas…)",
    "showsameroomosd-label": "Inkluzivi okazojn en via ĉambro",
    "shownoncontrollerosd-label": "Inkluzivi okazojn de neĉambrestroj en estrataj ĉambroj",
    "showdifferentroomosd-label": "Inkluzivi okazojn en aliaj ĉambroj",
    "showslowdownosd-label": "Inkluzivi sciigojn pri malrapidiĝoj / reiroj",
    "language-label": "Lingvo:",
    "automatic-language": "Implicita ({})",  # Default language
    "showdurationnotification-label": "Averti pri malakordo inter daŭroj de vidaŭdaĵoj",
    "basics-label": "Bazaj",
    "readiness-label": "Ludi/Paŭzigi",
    "misc-label": "Diversaj",
    "core-behaviour-title": "Baza konduto en ĉambroj",
    "syncplay-internals-title": "Internaĵoj de Syncplay",
    "syncplay-mediasearchdirectories-title": "Dosierujoj kun serĉotaj vidaŭdaĵoj",
    "syncplay-mediasearchdirectories-label": "Dosierujoj kun serĉotaj vidaŭdaĵoj (po unu vojo linie)",
    "sync-label": "Samtempigo",
    "sync-otherslagging-title": "Se aliuloj malfruas…",
    "sync-youlaggging-title": "Se vi malfruas…",
    "messages-label": "Mesaĝoj",
    "messages-osd-title": "Agordoj de ludila fasado",
    "messages-other-title": "Agordoj de aliaj montraĵoj",
    "chat-label": "Babilado",
    "privacy-label": "Privateco",  # Currently unused, but will be brought back if more space is needed in Misc tab
    "privacy-title": "Agordoj de privateco",
    "unpause-title": "Kiam vi premos ekludan butonon, markiĝi preta kaj:",
    "unpause-ifalreadyready-option": "Malpaŭzi se vi jam pretas",
    "unpause-ifothersready-option": "Malpaŭzi se vi aŭ aliuloj en la ĉambro jam pretas (implicita)",
    "unpause-ifminusersready-option": "Malpaŭzi se vi jam pretas, aŭ se ĉiuj aliaj pretas, kaj minimuma kvanto pretas",
    "unpause-always": "Ĉiam malpaŭzi",
    "syncplay-trusteddomains-title": "Fidataj retnomoj (por elsendfluoj kaj servado de enhavo)",

    "chat-title": "Enigo de babilaj mesaĝoj",
    "chatinputenabled-label": "Ŝalti babilan enigon per mpv",
    "chatdirectinput-label": "Permesi tujan babilan enigon (sen bezono premi la enigan klavon unue)",
    "chatinputfont-label": "Tiparo de babila enigo",
    "chatfont-label": "Agordi tiparon",
    "chatcolour-label": "Agordi koloron",
    "chatinputposition-label": "Pozicio de mesaĝa enigujo en mpv",
    "chat-top-option": "Supre",
    "chat-middle-option": "Meze",
    "chat-bottom-option": "Sube",
    "chatoutputheader-label": "Eligo de babilaj mesaĝoj",
    "chatoutputfont-label": "Tiparo de babila eligo",
    "chatoutputenabled-label": "Ŝalti babilan enigon en vidaŭdaĵa ludilo (ankoraŭ nur mpv)",
    "chatoutputposition-label": "Eliga reĝimo",
    "chat-chatroom-option": "Babilĉambro stilo",
    "chat-scrolling-option": "Ruluma stilo",

    "mpv-key-tab-hint": "[TAB] por aktivigi ŝparklavojn en alfabeta vico.",
    "mpv-key-hint": "[ENIG] por sendi mesaĝon. [ESKAP] por ĉesigi babilan reĝimon.",
    "alphakey-mode-warning-first-line": "Vi povas provizore uzi malnovajn ŝparklavojn de mpv per la klavoj a–z.",
    "alphakey-mode-warning-second-line": "Premu klavon [TAB] por reiri al babila reĝimo de Syncplay.",

    "help-label": "Helpo",
    "reset-label": "Reagordi implicitajn",
    "run-label": "Ruli programon Syncplay",
    "storeandrun-label": "Konservi agordaron kaj ruli programon Syncplay",

    "contact-label": "Laŭplaĉe sendu retleteron al <a href=\"mailto:dev@syncplay.pl\"><nobr>dev@syncplay.pl</nobr></a>, <a href=\"https://github.com/Syncplay/syncplay/issues\"><nobr>registru problemon</nobr></a> por raporti la eraron per GitHub, <a href=\"https://github.com/Syncplay/syncplay/discussions\"><nobr>komencu diskuton</nobr></a> por fari proponon aŭ meti demandon per GitHub, <a href=\"https://www.facebook.com/SyncplaySoftware\"><nobr>ŝatu nin ĉe Fejsbuko</nobr></a>, <a href=\"https://twitter.com/Syncplay/\"><nobr>abonu nin ĉe Tvitro</nobr></a>, aŭ vizitu al <a href=\"https://syncplay.pl/\"><nobr>https://syncplay.pl/</nobr></a>. Syncplay ne taŭgas por sendado de privataj aŭ sentigemaj informoj.",

    "joinroom-label": "Aliĝi al ĉambro",
    "joinroom-menu-label": "Aliĝi al ĉambro {}",
    "seektime-menu-label": "Iri al tempo",
    "undoseek-menu-label": "Reiri",
    "play-menu-label": "Ludi",
    "pause-menu-label": "Paŭzigi",
    "playbackbuttons-menu-label": "Montri ludbutonojn",
    "autoplay-menu-label": "Montri butonon por memaga ludado",
    "autoplay-guipushbuttonlabel": "Ludi kiam ĉiuj pretas",
    "autoplay-minimum-label": "Minimumo da uzantoj:",
    "hideemptyrooms-menu-label": "Kaŝi malplenajn persistajn ĉambrojn",

    "sendmessage-label": "Sendi",

    "ready-guipushbuttonlabel": "Mi pretas spekti!",

    "roomuser-heading-label": "Ĉambro / Uzanto",
    "size-heading-label": "Grandeco",
    "duration-heading-label": "Longeco",
    "filename-heading-label": "Dosiernomo",
    "notifications-heading-label": "Sciigoj",
    "userlist-heading-label": "Listo de nuna ludado",

    "browseformedia-label": "Foliumi vidaŭdaĵojn",

    "file-menu-label": "&Dosiero",  # & precedes shortcut key
    "openmedia-menu-label": "&Malfermi vidaŭdaĵon",
    "openstreamurl-menu-label": "Malfermi &vidaŭdfluan URL-on",
    "setmediadirectories-menu-label": "Agordi vidaŭdajn dosier&ujojn",
    "loadplaylistfromfile-menu-label": "&Enlegi ludliston de dosiero",
    "saveplaylisttofile-menu-label": "&Konservi ludliston al dosiero",
    "exit-menu-label": "Ĉesi&gi la programon",
    "advanced-menu-label": "&Altnivelaj",
    "window-menu-label": "&Fenestro",
    "setoffset-menu-label": "Agordi frue&con",
    "createcontrolledroom-menu-label": "&Krei estratan ĉambron",
    "identifyascontroller-menu-label": "&Identiĝi ĉambrestro",
    "settrusteddomains-menu-label": "Agordi fidatajn &retnomojn",
    "addtrusteddomain-menu-label": "Aldoni retnomon {} kiel fidatan",  # Domain

    "edit-menu-label": "&Redakti",
    "cut-menu-label": "El&tondi",
    "copy-menu-label": "&Kopii",
    "paste-menu-label": "&Alglui",
    "selectall-menu-label": "Ĉion &elekti",

    "playback-menu-label": "&Ludado",

    "help-menu-label": "&Helpo",
    "userguide-menu-label": "Malfermi &gvidilon por uzantoj",
    "update-menu-label": "Kontroli ĝisdati&gon",

    "startTLS-initiated": "Provas konektiĝi sekure",
    "startTLS-secure-connection-ok": "Konektiĝis sekure ({})",
    "startTLS-server-certificate-invalid": 'Malsukcesis konektiĝi sekure. La servilo uzas nevalidan atestilon pri sekureco. Iu povus subaŭskluti ĉi tiun komunikadon. Por pliaj detaloj kaj eblaj solvoj, vizitu <a href="https://syncplay.pl/trouble">ĉi tien</a>.',
    "startTLS-server-certificate-invalid-DNS-ID": "Syncplay ne fidas ĉi tiun servilon, ĉar ĝi uzas atestilon, kiu ne validas por la nomo de gastiga komputilo.",
    "startTLS-not-supported-client": "TLS ne estas subtenata de la kliento",
    "startTLS-not-supported-server": "TLS ne estas subtenata de la servilo",

    # TLS certificate dialog
    "tls-information-title": "Detaloj pri atestilo",
    "tls-dialog-status-label": "<strong>Syncplay uzas ĉifratan konekton al {}.</strong>",
    "tls-dialog-desc-label": "Ĉifrado kun cifereca atestilo lasas informojn privataj dum ili sendiĝas de aŭ al<br/>la servilo {}.",
    "tls-dialog-connection-label": "Informoj ĉifritaj per [Transport Layer Security] (TLS), versio {} kun la<br/>ĉifra ilaro: {}.",
    "tls-dialog-certificate-label": "Atestilo eldonita de {} kaj valida ĝis {}.",

    # About dialog
    "about-menu-label": "&Pri Syncplay",
    "about-dialog-title": "Pri Syncplay",
    "about-dialog-release": "Versio {}, eldono {}",
    "about-dialog-license-text": "Eldonita sub al permesilo «Apache&nbsp;License,&nbsp;Version 2.0»",
    "about-dialog-license-button": "Permesilo",
    "about-dialog-dependencies": "Dependoj",

    "setoffset-msgbox-label": "Agordi fruecon",
    "offsetinfo-msgbox-label": "Frueco (vidu instrukciojn ĉe https://syncplay.pl/guide/):",

    "promptforstreamurl-msgbox-label": "Malfermi URL-on al vidaŭdaĵa elsendfluo",
    "promptforstreamurlinfo-msgbox-label": "URL de elsendfluo",

    "addfolder-label": "Aldoni dosierujon",

    "adduris-msgbox-label": "Aldoni URL-ojn al ludlisto (po unu linie)",
    "editplaylist-msgbox-label": "Meti ludliston (po unu linie)",
    "trusteddomains-msgbox-label": "Retnomoj, kiujn oni rajtas memage viziti (po unu linie)",

    "createcontrolledroom-msgbox-label": "Krei estratan ĉambron",
    "controlledroominfo-msgbox-label": "Enigu nomon de estrata ĉambro\r\n(vidu al https://syncplay.pl/guide/ por instrukcioj pri uzado):",

    "identifyascontroller-msgbox-label": "Identiĝi ĉambrestro",
    "identifyinfo-msgbox-label": "Enigu ĉambrestran pasvorton por ĉi tiu ĉambro\r\n(vidu al https://syncplay.pl/guide/ por instrukcioj pri uzado):",

    "public-server-msgbox-label": "Elektu publikan servilon por ĉi tiu kunspekto",

    "megabyte-suffix": " MB",

    # Tooltips

    "host-tooltip": "Retnomo aŭ IP-adreso, al kiu vi konektiĝos, laŭplaĉe kun pordo (ekz. syncplay.pl:8999). Vi samtempiĝos nur kun personoj ĉe la sama servilo/pordo.",
    "name-tooltip": "Via prezenta kaŝnomo. Oni ne registriĝas, kaj vi povos facile ŝanĝi ĝin poste. Se vi elektos neniun, vi ricevos hazardan.",
    "password-tooltip": "Pasvortoj nur necesas por konektoj al privataj serviloj.",
    "room-tooltip": "Ĉambro, kiun vi eniros je konektiĝo, povas esti preskaŭ ĉio ajn, sed vi nur samtempiĝos kun personoj en la sama ĉambro.",

    "edit-rooms-tooltip": "Redakti liston de ĉambroj.",

    "executable-path-tooltip": "Loko de via elektita subtenata vidaŭdaĵa ludilo (mpv, mpv.net, VLC, MPC-HC/BE, mplayer2 aŭ IINA).",
    "media-path-tooltip": "Loko de filmo aŭ elsendfluo malfermota. Necesas por mplayer2.",
    "player-arguments-tooltip": "Aldonaj konzolaj parametroj / elektoj ricevotaj de ĉi tiu ludilo.",
    "mediasearcdirectories-arguments-tooltip": "Dosierujoj, en kiuj Syncplay serĉos vidaŭdaĵojn, ekz. kiam vi uzas la kapablon «klaki por ŝanĝi». Syncplay serĉos profunde en sub-dosierujoj.",

    "more-tooltip": "Montri malpli oftajn agordojn.",
    "filename-privacy-tooltip": "Privateca reĝimo por sendi nomon de nun ludata dosiero al la servilo.",
    "filesize-privacy-tooltip": "Privateca reĝimo por sendi grandecon de nun ludata dosiero al la servilo.",
    "privacy-sendraw-tooltip": "Sendi ĉi tiun informon senkaŝe. Ĉi tio estas la implicita agordo kun plej bona funkciado.",
    "privacy-sendhashed-tooltip": "Sendi haketitan version de la informo, kiu malpli evidentos por aliaj klientoj.",
    "privacy-dontsend-tooltip": "Ne sendi ĉi tiun informon al la servilo. Ĉi tio donas maksimuman privatecon.",
    "checkforupdatesautomatically-tooltip": "Kontroladi per la retejo de Syncplay, ĉu nova versio de Syncplay disponeblas.",
    "autosavejoinstolist-tooltip": "Kiam vi aliĝas al ĉambro en servilo, memage memoru la ĉambronomon en listo de aliĝotaj ĉambroj.",
    "slowondesync-tooltip": "malpliigi ludrapidecon kelkatempe, kiam vi bezonas resamtempiĝi kun aliaj spektantoj. Nesubtenata per MPC-HC/BE.",
    "dontslowdownwithme-tooltip": "Signifas, ke aliuloj ne malrapidiĝos nek reiros se via ludado prokrastiĝas. Utile por ĉambrestroj.",
    "pauseonleave-tooltip": "Paŭzigi kiam vi malkonektiĝas aŭ iu foriras de la ĉamrbo.",
    "readyatstart-tooltip": "Markiĝi «preta» je la komenco (alie vi estos «nepreta» ĝis vi mem ŝanĝos vian pretecon)",
    "forceguiprompt-tooltip": "Agorda fenestro ne montriĝas kiam vi malfermas dosieron per Syncplay.",  # (Inverted)
    "nostore-tooltip": "Syncplay ruliĝu kun la donita agordaro, sed ne memoru la ŝanĝojn poste.",  # (Inverted)
    "rewindondesync-tooltip": "Reiru kiam vi devas resamtempiĝi. Malŝalto de ĉi tiu elekto povas venigi gravajn diferencojn!",
    "fastforwardondesync-tooltip": "Saltu pluen pro misspegulado de ĉambrestro (aŭ ŝajnigu malveran pozicion, se «Neniam malrapidigi aŭ reirigi aliulojn» estas ŝaltita).",
    "showosd-tooltip": "Sendi mesaĝojn de Syncplay al fasado de la ludilo.",
    "showosdwarnings-tooltip": "Montri avertojn se ludiĝas alia dosiero, vi solas en ĉambro, uzantoj ne pretas, ktp.",
    "showsameroomosd-tooltip": "Montri fasade sciigojn pri okazoj rilataj al la ĉambro de la uzanto.",
    "shownoncontrollerosd-tooltip": "Montri fasade sciigojn pri okazoj rilataj al neĉambrestroj en estrataj ĉambroj.",
    "showdifferentroomosd-tooltip": "Montri fasade sciigojn pri okazoj rilata al ĉambro, en kiu la uzanto ne estas.",
    "showslowdownosd-tooltip": "Montri sciigojn pri malrapidiĝo / reiro pro tempa malakordo.",
    "showdurationnotification-tooltip": "Utilas kiam parto de plurparta dosiero mankas, sed fojfoje povas raporti problemojn erare.",
    "language-tooltip": "Lingvo uzota de Syncplay.",
    "unpause-always-tooltip": "Se vi malpaŭzos, vi ne nur pretiĝos, sed ĉiam ankaŭ malpaŭzos.",
    "unpause-ifalreadyready-tooltip": "Se vi malpaŭzigos nepreta, vi pretiĝos – malpaŭzigu refoje por vere malpaŭzigi.",
    "unpause-ifothersready-tooltip": "Se vi malpaŭzigos nepreta, vi nur malpaŭzigos se aliaj jam pretas.",
    "unpause-ifminusersready-tooltip": "Se vi malpaŭzigos nepreta, vi nur malpaŭzigos se aliaj jam pretas kaj minimuma limo de uzantoj atingiĝis.",
    "trusteddomains-arguments-tooltip": "Retnomoj, al kiuj Syncplay povas memage konektiĝi kiam komunaj ludlistoj estas ŝaltitaj.",

    "chatinputenabled-tooltip": "Ŝalti enigon de babilaj mesaĝoj en mpv (premu enigan klavon por enigi kaj sendi mesaĝojn, kaj eskapan klavon por nuligi)",
    "chatdirectinput-tooltip": "Ne atendi enigan klavon por babilado en mpv. Premu la tab-klavon por malŝalti provizore ĉi tiun kapablon.",
    "font-label-tooltip": "Tiparo uzata por enigo de babilaj mesaĝoj en mpv. Nur klient-flanke; ne influas aspekton por aliaj uzantoj.",
    "set-input-font-tooltip": "Familio de tiparo uzata por enigo de babilaj mesaĝoj en mpv. Nur klient-flanke; ne influas aspekton por aliaj uzantoj.",
    "set-input-colour-tooltip": "Koloro de tiparo uzata por enigo de babilaj mesaĝoj en mpv. Nur klient-flanke; ne influas aspekton por aliaj uzantoj.",
    "chatinputposition-tooltip": "Loko en mpv, kie eniga teksto aperos, kiam vi premos enigan klavon kaj tajpos.",
    "chatinputposition-top-tooltip": "Metu babilan enigon supre en la fenestro de mpv.",
    "chatinputposition-middle-tooltip": "Metu babilan enigon centre en la fenestro de mpv.",
    "chatinputposition-bottom-tooltip": "Metu babilan enigon sube en la fenestro de mpv.",
    "chatoutputenabled-tooltip": "Montru babilajn mesaĝojn en fasado (se vidaŭdaĵa ludilo tion subtenas).",
    "font-output-label-tooltip": "Tiparo por eligo de babilaj mesaĝoj.",
    "set-output-font-tooltip": "Tiparo uzota por montrado de babilaj mesaĝoj.",
    "chatoutputmode-tooltip": "Kiel babilaj mesaĝoj montriĝas.",
    "chatoutputmode-chatroom-tooltip": "Montri novajn liniojn de babilo rekte sub la lasta linio.",
    "chatoutputmode-scrolling-tooltip": "Rulumi babilan tekston maldekstren.",

    "help-tooltip": "Malfermas la gvidilon por uzantoj en Syncplay.pl.",
    "reset-tooltip": "Reagordas ĉion al komencaj valoroj.",
    "update-server-list-tooltip": "Konektiĝi al syncplay.pl por ĝisdatigi la liston de publikaj serviloj.",

    "sslconnection-tooltip": "Sekure konektiĝis al servilo. Klaku por detaloj pri atestilo.",

    "joinroom-tooltip": "Foriri de nuna ĉambro kaj aliĝi al donita ĉambro.",
    "seektime-msgbox-label": "Salti al donita tempo (en sekundoj / min:sek). Uzu la antaŭsignojn +/- por desalti.",
    "ready-tooltip": "Indikas, ĉu vi pretas spekti.",
    "autoplay-tooltip": "Memage ludi kiam ĉiuj uzantoj kun indikilo de preteco pretas, kaj minimuma kvanto de uzantoj ĉeestas.",
    "switch-to-file-tooltip": "Duoble klaku por ŝanĝi al {}",  # Filename
    "sendmessage-tooltip": "Sendi mesaĝon al ĉambro",

    # In-userlist notes (GUI)
    "differentsize-note": "Malsama grandeco!",
    "differentsizeandduration-note": "Malsamaj grandeco kaj daŭro!",
    "differentduration-note": "Malsama daŭro!",
    "nofile-note": "(Neniu dosiero ludiĝas)",

    # Server messages to client
    "new-syncplay-available-motd-message": "Vi uzas version {} de Syncplay, sed pli nova versio estas disponebla per https://syncplay.pl",  # ClientVersion
    "persistent-rooms-notice": "AVIZO: Ĉi tiu servilo uzas persistajn ĉámbrojn, kio signifas, ke la informoj pri ludlistoj konserviĝas por venontaj kunspektoj. Se vi volas krei ĉambron kie la informoj ne konserviĝas, finu la nomon de la ĉambro per «-temp».", # NOTE: Do not translate the word -temp
    "ready-chat-message": "I have set {} as ready.",  # User # TODO: Translate
    "not-ready-chat-message": "I have set {} as not ready.",  # User # TODO: Translate

    # Server notifications
    "welcome-server-notification": "Bonvenu al servilo de Syncplay, versio {0}",  # version
    "client-connected-room-server-notification": "{0}({2}) konektiĝis al ĉambro '{1}'",  # username, host, room
    "client-left-server-notification": "{0} foriris de la servilo",  # name
    "no-salt-notification": "BONVOLU SCII: Por ke pasvortoj de ĉambrestroj, estigitaj de ĉi tiu servilo, ankoraŭ funkciu post restarto de la servilo, bonvolu aldoni ĉi tiun konzolan parametron, kiam vi rerulos la servilon de Syncplay: --salt {}",  # Salt


    # Server arguments
    "server-argument-description": 'Solution to synchronize playback of multiple media player instances over the network. Server instance',
    "server-argument-epilog": 'Se neniuj elektoj estas donitaj, valoroj el _config uziĝos',
    "server-port-argument": 'TCP-pordo de la servilo',
    "server-password-argument": 'pasvorto de la servilo',
    "server-isolate-room-argument": 'ĉu ĉambroj estu izolitaj?',
    "server-salt-argument": "hazarda ĉeno uzata por estigi pasvortojn de estrataj ĉambroj",
    "server-disable-ready-argument": "malŝalti pretecon",
    "server-motd-argument": "vojo al dosiero, el kiu oni prenos mesaĝon de tago",
    "server-rooms-argument": "vojo al datumbaza dosiero por datumoj pri persistaj ĉambroj. Povigas ĉambrojn persisti sen spektantoj kaj inter restartigoj",
    "server-permanent-rooms-argument": "vojo al dosiero, kiu listigas persistajn ĉambrojn, kiuj listiĝos eĉ se ili malplenas (en la formo de teksta dosiero, kiu listigas po unu ĉambro linie) – postulas persistajn ĉambrojn ŝaltitajn",
    "server-chat-argument": "Ĉu babilado estu malŝaltita?",
    "server-chat-maxchars-argument": "Maksimuma kvanto de signoj en babila mesaĝo (implicita valoro estas {})", # Default number of characters
    "server-maxusernamelength-argument": "Maksimuma kvanto de signoj en uzantonomo (implicita valoro estas {})",
    "server-stats-db-file-argument": "Ŝalti servilajn statistikojn per la donita datumbaza dosiero de SQLite",
    "server-startTLS-argument": "Ŝalti TLS-konektojn per la atestilaj dosieroj en la donita vojo",
    "server-messed-up-motd-unescaped-placeholders": "Mesaĝo de tago havas neŝirmitajn anstataŭiĝojn. Ĉiuj dolarsignoj devus aperi duoble ($$).",
    "server-messed-up-motd-too-long": "Mesaĝo de tago estas tro longa – maksimuma kvanto estas {} signoj, sed {} estas donitaj.",
    "server-listen-only-on-ipv4": "Listen only on IPv4 when starting the server.",
    "server-listen-only-on-ipv6": "Listen only on IPv6 when starting the server.",
    "server-interface-ipv4": "The IP address to bind to for IPv4. Leaving it empty defaults to using all.",
    "server-interface-ipv6": "The IP address to bind to for IPv6. Leaving it empty defaults to using all.",

    # Server errors
    "unknown-command-server-error": "Nekonata ordono {}",  # message
    "not-json-server-error": "{} ne estas teksto kodita por JSON",  # message
    "line-decode-server-error": "{} ne estas teksto kodita per UTF-8",
    "not-known-server-error": "La servilo devas koni vin, antaŭ ol vi sendos ĉi tiun ordonon",
    "client-drop-server-error": "Client drop: {} -- {}",  # host, error # FARU: Mi ne komprenas.
    "password-required-server-error": "Necesas pasvorto",
    "wrong-password-server-error": "Malĝusta pasvorto estas donita",
    "hello-server-error": "Not enough Hello arguments",  # DO NOT TRANSLATE # Okay, geez, no need to shout!

    # Playlists
    "playlist-selection-changed-notification":  "{} ŝanĝis la elekton de ludlisto",  # Username
    "playlist-contents-changed-notification": "{} ĝisdatigis la ludliston",  # Username
    "cannot-find-file-for-playlist-switch-error": "Ne trovis la dosieron {} en vidaŭdaĵaj dosierujoj por ludlista ŝanĝo!",  # Filename
    "cannot-add-duplicate-error": "Ne povis aldoni duan listeron «{}» al la ludlisto ĉar duoblaĵoj ne estas permesitaj.",  # Filename
    "cannot-add-unsafe-path-error": "Ne povis memage enlegi el {}, ĉar ĝi ne estas fidata retnomo. Vi povas iri al la URL permane, se vi duoble klakos ĝin en la ludlisto, kaj aldoni fidatajn retnomojn per la menuero «Dosiero → Altnivelaj → Agordi fidatajn retnomojn». Se vi dekstre klakos al URL, vi povos fidi ĝian retnomon per la kunteksta menuo",  # Filename
    "sharedplaylistenabled-label": "Ŝalti komunajn ludlistojn",
    "removefromplaylist-menu-label": "Forigi de ludlisto",
    "shuffleremainingplaylist-menu-label": "Miksi ceteron de ludlisto",
    "shuffleentireplaylist-menu-label": "Miksi tutan ludliston",
    "undoplaylist-menu-label": "Malfari lastan ŝanĝon al ludlisto",
    "addfilestoplaylist-menu-label": "Aldoni dosiero(j)n al fino de ludlisto",
    "addurlstoplaylist-menu-label": "Aldoni URL-o(j)n al fino de ludlisto",
    "editplaylist-menu-label": "Redakti ludliston",

    "open-containing-folder": "Malfermi dosierujon kun ĉi tiu dosiero",
    "addyourfiletoplaylist-menu-label": "Aldoni vian dosieron al la ludlisto",
    "addotherusersfiletoplaylist-menu-label": "Aldoni dosieron de {} al la ludlisto",  # [Username]
    "addyourstreamstoplaylist-menu-label": "Aldoni vian elsendon al la ludlisto",
    "addotherusersstreamstoplaylist-menu-label": "Aldoni elsendon de {} al la ludlisto",  # [Username]
    "openusersstream-menu-label": "Malfermi elsendon de {}",  # [username]'s
    "openusersfile-menu-label": "Malfermi dosieron de {}",  # [username]'s

    "setasready-menu-label": "Set {} as ready",  # [Username] # TODO: Translate
    "setasnotready-menu-label": "Set {} as not ready",  # [Username] # TODO: Translate

    "playlist-instruction-item-message": "Metu dosieron ĉi tien por aldoni ĝin al la komuna ludlisto.",
    "sharedplaylistenabled-tooltip": "Ĉambrestroj povas aldoni dosierojn al spegulata ludlisto, por ke ĉiuj povu facile spekti la saman filmon. Agordu vidaŭdaĵajn dosierojn sub «Diversaj».",

    "playlist-empty-error": "Ludlisto nun estas malplena.",
    "playlist-invalid-index-error": "Nevalida indico de ludlisto",
}
